@@ -4,7 +4,7 @@
     begin                : Fri Sep 15 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.16 $
+    revision             : $Revision: 1.19 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -16,13 +16,14 @@
 
 #include <qtooltip.h>
 #include <qlayout.h>
+#include <klocale.h>
 #include <qhbox.h>
 #include "kmagodoc.h"
 #include "kdlgapp.h"
 
 
 KDlgApp::KDlgApp(KMagoDoc *doc, QWidget *parent, const char *name) :
-   QWidget(parent, name), _doc(doc) 
+   KTabCtl(parent, name), _doc(doc)
 {
    initDialog();
    init();
@@ -37,18 +38,21 @@ KMagoDoc * KDlgApp::doc() const
    return _doc;
 }
 
-void KDlgApp::init() 
+void KDlgApp::init()
 {
    cbtAEFile->setChecked(doc()->getOpenFlags() & FLG_FILE_AUTO_ENCODE);
    cbtNoPrompt->setChecked(doc()->getOpenFlags() & FLG_NO_PROMPT);
    cbtFEFile->setChecked(doc()->getOpenFlags() & FLG_FILE_FORCE_ENCODE);
    cbtLoadLast->setChecked(doc()->getLoadLastDoc());
-   cbtExitOnIdle->setChecked(doc()->getExitOnIdle());
    lneUpdateInt->setText(QString().setNum(doc()->getUpdateTime()));
    lneSaveInt->setText(QString().setNum(doc()->getSaveTime()));
    lneTStart->setText(QString::number(doc()->getTransferStartTime()));
    cbtListOnDrop->setChecked(doc()->getListOnDrop());
-   switch (doc()->getStartMode()) 
+   cbtNotify->setChecked(doc()->getEnableNotify());
+   cbtAutoProgress->setChecked(doc()->getAutoProgress());
+   cbtTrayProgress->setChecked(doc()->getTrayProgress());
+   lneCmdOnIdle->setText(doc()->getCommandOnIdle());
+   switch (doc()->getStartMode())
    {
    case START_NOW:
       rbtStart0->setChecked(true);
@@ -65,10 +69,15 @@ void KDlgApp::init()
 
 void  KDlgApp::initDialog()
 {
-   QBoxLayout * l = new QVBoxLayout(this, 8);
+   //first page
 
-   QGroupBox *gbox = new QGroupBox(1, Horizontal, this, "GB1");
-   gbox->setTitle(i18n("General"));
+   QWidget *page = new QWidget(this);
+   addTab(page, i18n("General"));
+
+   QBoxLayout * l = new QVBoxLayout(page, 8);
+
+   QGroupBox *gbox = new QGroupBox(1, Horizontal, page, "GB1");
+   gbox->setTitle(i18n("Timings"));
    l->addWidget(gbox);
 
    QHBox *box = new QHBox(gbox);
@@ -97,6 +106,10 @@ void  KDlgApp::initDialog()
    box->setStretchFactor(lbl, 1);
    box->setStretchFactor(lneUpdateInt, 0);
 
+   gbox = new QGroupBox(1, Horizontal, page, "GB2");
+   gbox->setTitle(i18n("General"));
+   l->addWidget(gbox);
+
    cbtExpert = new QCheckBox(gbox, "CbtExpert");
    QToolTip::add(cbtExpert,i18n("No confirmation for destructive actions"));
    cbtExpert->setText(i18n("Expert mode: no confirmation prompt"));
@@ -109,11 +122,37 @@ void  KDlgApp::initDialog()
    QToolTip::add(cbtListOnDrop, i18n("Popup managers list menu dropping on tray icon or drop target"));
    cbtListOnDrop->setText(i18n("Popup a list of managers on drop"));
 
-   cbtExitOnIdle = new QCheckBox(gbox, "CbtExitOnIdle");
-   QToolTip::add(cbtExitOnIdle, i18n("Exit if no transfers are left to run"));
-   cbtExitOnIdle->setText(i18n("Exit if no transfers are left to run"));
+   cbtNotify = new QCheckBox(gbox, "CbtNotify");
+   QToolTip::add(cbtNotify, i18n("Enable event notification on transfer error, start, complete, ..."));
+   cbtNotify->setText(i18n("Enable event notification"));
 
-   gbox = new QGroupBox(1, Horizontal, this, "GB2");
+   cbtAutoProgress = new QCheckBox(gbox, "CbtAutoProgress");
+   QToolTip::add(cbtAutoProgress, i18n("Automatic opening and closing of progress windows on transfer's start and complete"));
+   cbtAutoProgress->setText(i18n("Automatic pop up of progress windows"));
+
+   cbtTrayProgress = new QCheckBox(gbox, "CbtTrayProgress");
+   QToolTip::add(cbtTrayProgress, i18n("Add a system tray icon to progress window"));
+   cbtTrayProgress->setText(i18n("Add system tray icon to progress windows"));
+
+   box = new QHBox(gbox);
+   lbl = new QLabel(i18n("Idle Command"), box, "LblCmdOnIdle");
+   lneCmdOnIdle = new QLineEdit(box, "LneCmdOnIdle");
+   //lneCmdOnIdle->setFixedWidth(lneCmdOnIdle->fontMetrics().width("XXXXXXXX"));
+   QToolTip::add(lneCmdOnIdle, i18n("Command to execute on first idle state"));
+   box->setStretchFactor(lbl, 1);
+   box->setStretchFactor(lneCmdOnIdle, 10);
+
+   page->adjustSize();
+   page->setMinimumSize(size());
+
+   // second page
+
+   page = new QWidget(this);
+   addTab(page, i18n("Input Control"));
+
+   l = new QVBoxLayout(page, 8);
+
+   gbox = new QGroupBox(1, Horizontal, page, "GB3");
    gbox->setTitle(i18n("Input Validation"));
    l->addWidget(gbox);
 
@@ -132,12 +171,12 @@ void  KDlgApp::initDialog()
 		 i18n("Force filename encoding when it contain spaces"));
    cbtFEFile->setText(i18n("Force filename encoding"));
 
-   QButtonGroup * bg = new QButtonGroup(1, Horizontal, this, "BgrStart");
+   QButtonGroup * bg = new QButtonGroup(1, Horizontal, page, "BgrStart");
    bg->setTitle(i18n("Adding Transfer Mode"));
    l->addWidget(bg);
 
    rbtStart0 = new QRadioButton(bg,"RbtStart0");
-   rbtStart0->setText(i18n("Start download immediatly"));
+   rbtStart0->setText(i18n("Start download immediately"));
 
    rbtStart1 = new QRadioButton(bg,"RbtStart1");
    rbtStart1->setText(i18n("Prompt to start or add to list"));
@@ -145,11 +184,14 @@ void  KDlgApp::initDialog()
    rbtStart2 = new QRadioButton(bg,"RbtStart2");
    rbtStart2->setText(i18n("Add to list"));
 
+   page->adjustSize();
+   page->setMinimumSize(size());
+
    adjustSize();
-   setMinimumSize(size()); //FIXME this doesn't work
+   setMinimumSize(size());
 }
 
-bool KDlgApp::isAcceptable() 
+bool KDlgApp::isAcceptable()
 {
    bool check;
    QString(lneUpdateInt->text()).toInt(&check);
@@ -163,7 +205,7 @@ bool KDlgApp::isAcceptable()
    return true;
 }
 
-void KDlgApp::accept() 
+void KDlgApp::accept()
 {
    int f = ((cbtAEFile->isChecked() ? FLG_FILE_AUTO_ENCODE : 0)
 	    + (cbtFEFile->isChecked() ? FLG_FILE_FORCE_ENCODE : 0)
@@ -175,8 +217,11 @@ void KDlgApp::accept()
    doc()->setStartMode(getStartMode());
    doc()->setExpertMode(cbtExpert->isChecked());
    doc()->setLoadLastDoc(cbtLoadLast->isChecked());
-   doc()->setExitOnIdle(cbtExitOnIdle->isChecked());
    doc()->setListOnDrop(cbtListOnDrop->isChecked());
+   doc()->setEnableNotify(cbtNotify->isChecked());
+   doc()->setAutoProgress(cbtAutoProgress->isChecked());
+   doc()->setTrayProgress(cbtTrayProgress->isChecked());
+   doc()->setCommandOnIdle(lneCmdOnIdle->text());
    doc()->saveState();
    KMagoDoc::reloadState();
 }
@@ -187,8 +232,8 @@ void KDlgApp::reject()
 
 int KDlgApp::getStartMode()
 {
-   return (rbtStart0->isChecked() * START_NOW 
-	   + rbtStart1->isChecked() * START_PROMPT 
+   return (rbtStart0->isChecked() * START_NOW
+	   + rbtStart1->isChecked() * START_PROMPT
 	   + rbtStart2->isChecked() * START_NO);
 }
 
