@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.11 $
+    revision             : $Revision: 1.12 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -56,7 +56,7 @@ void KDlgTransfer::initDialog()
    QVBox *page = addVBoxPage(i18n("Settings"));
    _ps = new KDlgTransferSet(_t, page);
 
-   page = addVBoxPage(i18n(QString("%1 1").arg(KObject::typeStr(_t.type()))));
+   page = addVBoxPage(QString("%1 1").arg(KObject::typeStr(_t.type())));
    _p1 = new KDlgTransfer1(_t, page);
 
 #ifdef ENABLE_WGET
