@@ -4,7 +4,7 @@
     begin                : Thu Aug 31 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.9 $
+    revision             : $Revision: 1.10 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -14,21 +14,23 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <cstdlib>
+//#include <cstdlib>
 #include <qlayout.h>
+#include <qpushbutton.h>
+#include <klocale.h>
 #include "ktransfer.h"
 #include "klogviewer.h"
 
-KLogViewer::KLogViewer(KTransfer t, QWidget *parent, const char *name) : 
+KLogViewer::KLogViewer(KTransfer t, QWidget *parent, const char *name) :
    QWidget(parent, name,
-	   WDestructiveClose 
-	   | WType_TopLevel | WStyle_Customize | WStyle_NormalBorder 
-	   | WStyle_Title | WStyle_SysMenu | WStyle_MinMax) 
+	   WDestructiveClose
+	   | WType_TopLevel | WStyle_Customize | WStyle_NormalBorder
+	   | WStyle_Title | WStyle_SysMenu | WStyle_MinMax)
 {
    _id = t.id();
    initDialog();
    setCaption("Log: " + t.remote().prettyURL());
-   t.connect(SIGNAL(sigProcessOutput(const QString &)), 
+   t.connect(SIGNAL(sigProcessOutput(const QString &)),
 	     this, SLOT(slotRead(const QString &)));
 }
 
@@ -55,7 +57,7 @@ void  KLogViewer::initDialog()
    l->addWidget(btnOK, 0, AlignRight);
 }
 
-void KLogViewer::slotRead(const QString &data) 
+void KLogViewer::slotRead(const QString &data)
 {
    int l, c;
    mleText->getCursorPosition(&l, &c);
