@@ -4,7 +4,7 @@
     begin                : Tue Oct 17 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.20 $
+    revision             : $Revision: 1.22 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,19 +29,19 @@
 #include <qdom.h>
 #include <qbitarray.h>
 
-/** 
+/**
  * @short namespace containing all common defs for KMago.
  *
  * @author Sergio Moretti
  *
- * @version $Id: km.h,v 1.20 2001/03/18 16:31:03 sergio Exp $
+ * @version $Id: km.h,v 1.22 2001/04/02 20:38:51 sergio Exp $
  */
 
-namespace KM 
+namespace KM
 {
 
    /** debug areas */
-   enum DebugAreas 
+   enum DebugAreas
    {
       D_INI =    41000,
       D_VIE =    41001,
@@ -54,13 +54,13 @@ namespace KM
     *
     * @author Sergio Moretti
     *
-    * @version $Id: km.h,v 1.20 2001/03/18 16:31:03 sergio Exp $
+    * @version $Id: km.h,v 1.22 2001/04/02 20:38:51 sergio Exp $
     */
-  
-   class Error /* : public exception */ 
+
+   class Error /* : public exception */
    {
    public:
-      Error(const QString &name, const QString &descr) 
+      Error(const QString &name, const QString &descr)
 	 {
 	    _what = QString("%1: %2").arg(name).arg(descr);
 	    //cerr << _what << endl;
@@ -73,26 +73,26 @@ namespace KM
       QString _what;
    };
 
-  
+
    /**
     * @short Exception related to DOM errors.
     *
     * @author Sergio Moretti
     *
-    * @version $Id: km.h,v 1.20 2001/03/18 16:31:03 sergio Exp $
+    * @version $Id: km.h,v 1.22 2001/04/02 20:38:51 sergio Exp $
     */
-  
-   class DomError : public Error 
+
+   class DomError : public Error
    {
    public:
-      DomError(const QString &name, const QString &descr, QDomDocument doc) 
+      DomError(const QString &name, const QString &descr, QDomDocument doc)
 	 : Error(name, QString("%1:\n%2").arg(descr).arg(doc.toString())) {}
-      DomError(const QString &name, const QString &descr, QDomNode n) 
+      DomError(const QString &name, const QString &descr, QDomNode n)
 	 : Error(name, QString("%1:\n%2").arg(descr).arg(n.ownerDocument().toString())) {}
    };
 
    /**
-    * Object types: 
+    * Object types:
     * @li TYP_*_T mask type
     * @li TYP_* type id of an object
     */
@@ -166,6 +166,7 @@ namespace KM
       MDI_TRW_CFG_IGNLEN,
       // kio transfer
       MDI_TRK_CFG_COOKIE,
+      MDI_TRK_CFG_CACHE,
       // tmanager
       MDI_TMN_TITLE,
       MDI_TMN_CFG_AUTODWNL,
@@ -176,32 +177,18 @@ namespace KM
       // mmanager
       MDI_MMN_DLOCK,
       MDI_MMN_IDLE,
-      
+
       MDI_NUM
    };
 
    typedef QBitArray ModFlags;
 
-   /**
-    * Modification state propagation mode:
-    * @li PRP_NONE : no propagation
-    * @li PRP_THIS : propagation of nofication for this object only
-    * @li PRP_ALL  : propagation of notifications for all objects in calling 
-    object's hierarchy.
-   */
-   enum PropMode 
-   {
-      PRP_NONE,
-      PRP_THIS,
-      PRP_ALL
-   };
-
    // TRANSFER
 
    /**
     * Transfer state
     */
-   enum TrnState 
+   enum TrnState
    {
       TRN_READY = 0,
       TRN_START,
@@ -213,11 +200,11 @@ namespace KM
       TRN_END_KILL,
       TRN_END_READY
    };
-  
+
    /**
     * Transfer resume status
     */
-   enum RsmState 
+   enum RsmState
    {
       RSM_UNKNOWN = 0,
       RSM_CHECKING,
@@ -225,11 +212,11 @@ namespace KM
       RSM_YES,
       RSM_NO
    };
-  
+
    /**
     * Priority policy for transfer activation selection.
     */
-   enum PriorityPolicy 
+   enum PriorityPolicy
    {
       PRI_FIFO = 0,
       PRI_LIFO,
@@ -256,7 +243,7 @@ namespace KM
    // WGET
 
    /** protocols supported */
-   enum Protocol 
+   enum Protocol
    {
       FTP = 1,
       HTTP
@@ -265,7 +252,7 @@ namespace KM
    /**
     * Wget categories for transfer bandwidth.
     */
-   enum TransferSpeed 
+   enum TransferSpeed
    {
       SPD_DEFAULT = 0,
       SPD_BINARY,
@@ -275,32 +262,36 @@ namespace KM
 
    // END WGET
 
-   // KMAGOAPP
-  
+   // KMAGODOC
+
    /**
     * Flags to control transfer insertion.
     */
-   enum OpenFlags 
+   enum OpenFlags
    {
       FLG_FILE_AUTO_ENCODE =   0x001,
       FLG_FILE_FORCE_ENCODE =  0x002,
       FLG_NO_PROMPT =          0x004
    };
-  
+
    /**
     * action to perform on transfer insertion.
     */
-   enum StartMode 
+   enum StartMode
    {
       START_NOW    = 0,
       START_PROMPT,
       START_NO
    };
-  
+
+   // END KMAGODOC
+
+   // KMAGOAPP
+
    /**
     * identificators for status labels
     */
-   enum IDs 
+   enum IDs
    {
       STATUS_MSG   = 0,
       STATUS_COUNT,
