@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.33 $
+    revision             : $Revision: 1.36 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -46,11 +46,11 @@ class KDropper;
 
 /**
  * @short Base class for KMago application windows.
- * 
+ *
  * @author Sergio Moretti
- * 
- * @version $Id: kmago.h,v 1.33 2001/03/23 17:14:59 sergio Exp $
- * 
+ *
+ * @version $Id: kmago.h,v 1.36 2001/04/04 18:06:04 sergio Exp $
+ *
  * The base class for KMago application windows. It sets up the main
  * window and reads the config file as well as providing a menubar, toolbar
  * and statusbar. An instance of KMagoView creates your center view, which is connected
@@ -61,7 +61,7 @@ class KDropper;
  * @see KAccel
  */
 
-class KMagoApp : public KMainWindow 
+class KMagoApp : public KMainWindow
 {
    Q_OBJECT
 
@@ -70,7 +70,7 @@ class KMagoApp : public KMainWindow
    static const char IDS_STATUS_DEFAULT[];
 
 public:
-   /** 
+   /**
     * construtor of KMagoApp, calls all init functions to create the application.
     * @see initMenuBar initToolBar
     */
@@ -78,10 +78,10 @@ public:
    ~KMagoApp();
 
    /**
-    * returns a pointer to the current document connected to the KMainWindow 
-    * instance and is used by the View class to access the document object's 
+    * returns a pointer to the current document connected to the KMainWindow
+    * instance and is used by the View class to access the document object's
     * methods
-    */	
+    */
    KMagoDoc *doc() const { return _doc; }
    KSysTrayView *sysTray() const { return _sysTray; }
    KMagoView *view() const { return _view; }
@@ -89,6 +89,8 @@ public:
    //KMManager mainManager() const;
 
    void setDownloadLock(bool v);
+   void setExitOnIdle(bool v);
+   void setExecuteOnIdle(bool v);
 
    void updateCaption();
    void updateStatusBarCount();
@@ -103,37 +105,37 @@ public:
 
    // configuration
 
-protected:  
+protected:
    /** initActions creates the actions for menus and toolbars */
    void initActions();
    /** sets up the statusbar for the main window by initialzing a statuslabel. */
    void initStatusBar();
-   /** 
-    * initializes the document object of the main window that is connected to 
+   /**
+    * initializes the document object of the main window that is connected to
     * the view in initView().
     * @see initView();
     */
    void initDocument();
    /**
-    * creates the centerwidget of the KTMainWindow instance and sets it as the 
-    * view 
+    * creates the centerwidget of the KTMainWindow instance and sets it as the
+    * view
     */
    void initView();
    /** create the system tray widget */
    void initSysTray();
    /**
-    * queryClose is called by KTMainWindow on each closeEvent of a window. 
-    * Against the default implementation (only returns true), this calles 
+    * queryClose is called by KTMainWindow on each closeEvent of a window.
+    * Against the default implementation (only returns true), this calles
     * saveModified() on the document object to ask if the document shall
     * be saved if Modified; on cancel the closeEvent is rejected.
     * @see KMainWindow#queryClose
     * @see KMainWindow#closeEvent
     */
    virtual bool queryClose();
-   /** 
-    * queryExit is called by KTMainWindow when the last window of the 
+   /**
+    * queryExit is called by KTMainWindow when the last window of the
     * application is going to be closed during the closeEvent().
-    * Against the default implementation that just returns true, this calls 
+    * Against the default implementation that just returns true, this calls
     * saveOptions() to save the settings of the last window's properties.
     * @see KMainWindow#queryExit
     * @see KMainWindow#closeEvent
@@ -145,21 +147,23 @@ protected:
    /** save main window settings */
    void  saveSettings(KConfig *config, bool toSession);
 
-   /** 
-    * saves the window properties for each open window during session end to 
+   /**
+    * saves the window properties for each open window during session end to
     * the session config file, including saving the currently
     * opened file by a temporary filename provided by KApplication.
     * @see KMainWindow#saveProperties
     */
    virtual void saveProperties(KConfig *config);
-   /** 
-    * reads the session config file and restores the application's state 
+   /**
+    * reads the session config file and restores the application's state
     * including the last opened files and documents by reading the
     * temporary files saved by saveProperties()
     * @see KMainWindow#readProperties
     */
    virtual void readProperties(KConfig *config);
-  
+
+   /** open transfer progress window */
+   void openTransferProgress(KTransfer t);
    /** close all windows related to transfer */
    void closeTransferWindows(KTransfer t);
 
@@ -176,8 +180,8 @@ protected slots:
    void slotFileOpenRecent(const KURL &url);
    /** save a document by a new filename */
    void slotFileSaveAs();
-   /** 
-    * asks for saving if the file is modified, then closes the actual file 
+   /**
+    * asks for saving if the file is modified, then closes the actual file
     * and window
     */
    void slotFileClose();
@@ -190,8 +194,8 @@ protected slots:
    /** automatic download locking */
    void slotFileDownloadLock();
 
-   /** 
-    * put the marked text/object into the clipboard and remove it from 
+   /**
+    * put the marked text/object into the clipboard and remove it from
     * the document
     */
    void slotEditCut();
@@ -201,11 +205,9 @@ protected slots:
    void slotEditPaste();
    /** unselect the current transfer */
    void slotEditUnselectTransfer();
-  
+
    /** add a new transfer to the transfers list */
    void slotManagerAdd();
-   /** add a new transfer from pasting */
-   void slotManagerPaste();
    /** add a transfer from the recent transfers list */
    void slotManagerAddRecent(const KURL& u);
    /** enable/disable auto-downloading mode */
@@ -226,7 +228,17 @@ protected slots:
    void slotManagerIncrPriority();
    /** decrease manager priority by 1 */
    void slotManagerDecrPriority();
-  
+   void slotManagerCut();
+   void slotManagerCopy();
+   /** add a new transfer from pasting */
+   void slotManagerPaste();
+   /** enable/disable exiting on idle */
+   void slotManagerExitOnIdle();
+   /** kill all active transfers */
+   void slotKillAll();
+   /** enable/disable execute command on first idle state */
+   void slotExecuteOnIdle();
+
    /** start/resume transfer*/
    void slotTransferStartStop();
    /** remove transfer*/
@@ -257,7 +269,10 @@ protected slots:
    void slotTransferDecrPriority();
    /** reset transfer state */
    void slotTransferSetState();
-  
+   void slotTransferCut();
+   void slotTransferCopy();
+   void slotTransferProgress();
+
    /** toggles the main toolbar*/
    void slotViewToolBarMain();
    /** toggles the managers toolbar*/
@@ -284,30 +299,31 @@ protected slots:
    /** save options */
    void slotSaveOptions();
 
-   /** 
-    * changes the statusbar contents for the standard label permanently, used 
+   /**
+    * changes the statusbar contents for the standard label permanently, used
     * to indicate current actions.
     * @param text the text that is displayed in the statusbar
     */
    void slotStatusMsg(const QString &text);
-   /** 
-    * changes the status message of the whole statusbar for two seconds, then 
+   /**
+    * changes the status message of the whole statusbar for two seconds, then
     * restores the last status. This is used to display
-    * statusbar messages that give information about actions for toolbar icons 
+    * statusbar messages that give information about actions for toolbar icons
     * and menuentries.
     * @param text the text that is displayed in the statusbar
     */
    void slotStatusHelpMsg(const QString &text);
-  
+
    /** called when clipboard data change */
    void slotClipboardChange();
 
 protected slots:
    void slotWndStatusClosed(int id);
    void slotWndLogClosed(int id);
+   void slotWndProgressClosed(int id);
 
 private:
-   /** 
+   /**
     * view is the main widget which represents your working area. The View
     * class should handle all events of the view widget.  It is kept empty so
     * you can create your view according to your application's needs by
@@ -318,7 +334,7 @@ private:
    KSysTrayView *_sysTray;
    /** dropper window */
    KDropper *_dropper;
-   /** 
+   /**
     * doc represents your actual document and is created only once. It keeps
     * information such as filename and does the serialization of your files.
     */
@@ -327,10 +343,12 @@ private:
    QIntDict<QWidget> _logWnds;
    /** dictionary id/window of open status windows */
    QIntDict<QWidget> _statusWnds;
-  
+   /** dictionary id/window of open progress windows */
+   QIntDict<QWidget> _progressWnds;
+
    // actions
    KAction
-   *fileNewWindow,
+      *fileNewWindow,
       *fileNew,
       *fileOpen,
       *fileClose,
@@ -344,12 +362,15 @@ private:
       *editUnselectTransfer,
       *managerAdd,
       *managerConf,
-      *managerPaste,
       *managerKillAll,
       *managerRemoveMngr,
       *managerClear,
       *managerSetIncrPriority,
       *managerSetDecrPriority,
+      *managerCut,
+      *managerCopy,
+      *managerPaste,
+      *killAll,
       *transferCheck,
       *transferConf,
       *transferRemove,
@@ -361,15 +382,20 @@ private:
       *transferSetIncrPriority,
       *transferSetDecrPriority,
       *transferSetState,
+      *transferCut,
+      *transferCopy,
+      *transferProgress,
       *viewRefresh,
       *viewPrefs,
       *separator;
    KRecentFilesAction
-   *fileOpenRecent,
+      *fileOpenRecent,
       *managerAddRecent;
    KToggleAction
-   *fileDownloadLock,
+      *fileDownloadLock,
       *managerAutoDownload,
+      *managerExitOnIdle,
+      *executeOnIdle,
       *transferAutoCheck,
       *transferAutoResume,
       *viewStatusBar,
@@ -379,8 +405,8 @@ private:
       *viewManagers,
       *viewSysTray,
       *viewDropper;
-   KListAction 
-   *fileSelectMngr,
+   KListAction
+      *fileSelectMngr,
       *managerSetPriority,
       *transferSetPriority,
       *transferSetRsmState;
