@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.23 $
+    revision             : $Revision: 1.27 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,28 +22,31 @@
 #include <kapp.h>
 #include <kdebug.h>
 #include <klocale.h>
+#include <knotifyclient.h>
 #include "utils.h"
 #include "kcntiterator.h"
 #include "kmago.h"
 #include "kmagoview.h"
 #include "kcontainerview.h"
 #include "kdlgopentransfer.h"
+#include "ksystrayview.h"
 #include "kmagodoc.h"
 
 
-KMagoBugReport::KMagoBugReport(QWidget * parent, bool modal, 
-			       const KAboutData *aboutData) 
-   : KBugReport(parent, modal, aboutData) 
+KMagoBugReport::KMagoBugReport(QWidget * parent, bool modal,
+			       const KAboutData *aboutData)
+   : KBugReport(parent, modal, aboutData)
 {
 }
 
-void KMagoBugReport::appendLine(const QString &line) 
+void KMagoBugReport::appendLine(const QString &line)
 {
    m_lineedit->insertLine(line);
 }
 
+/////////////////////////////////////////////////////////////////
 
-void KMagoDoc::NotifyChange::operator()(const KObject obj) const 
+void KMagoDoc::NotifyChange::operator()(const KObject obj) const
 {
    kdFatal(_doc->isClosed(), D_RUN) << _doc->name() << ": notify on closed doc" << endl;
    //_doc->mainView()->updateView(obj);
@@ -53,8 +56,11 @@ void KMagoDoc::NotifyChange::operator()(const KObject obj) const
       emit _doc->sigTransferChange(obj.toTransfer());
 }
 
-KMagoDoc::KMagoDoc(KMagoApp *parent, const char *name) 
-   : QObject(parent, name), _app(parent), _title(i18n("Untitled")), _tmp(false)
+/////////////////////////////////////////////////////////////////
+
+KMagoDoc::KMagoDoc(KMagoApp *parent, const char *name)
+   : QObject(parent, name), _app(parent), _title(i18n("Untitled")), _tmp(false),
+_exitOnIdle(false), _firstIdle(true), _executeOnIdle(false)
 {
    KObject::initFactory();
    //_timerUpd = new QTimer(this);
@@ -67,7 +73,7 @@ KMagoDoc::KMagoDoc(KMagoApp *parent, const char *name)
    _curTransferDict.setAutoDelete(true);
 }
 
-KMagoDoc::~KMagoDoc() 
+KMagoDoc::~KMagoDoc()
 {
    kdDebug(D_INI) << name() << " destroy" << endl;
    if (!isClosed())
@@ -75,7 +81,7 @@ KMagoDoc::~KMagoDoc()
    //KObject::deleteFactory(); FIXME find a place to call this
 }
 
-KMagoApp * KMagoDoc::mainView() const 
+KMagoApp * KMagoDoc::mainView() const
 {
    return _app;
 }
@@ -85,18 +91,18 @@ KMainWindow * KMagoDoc::mainWindow() const
    return _app;
 }
 
-KMagoView * KMagoDoc::view() const 
+KMagoView * KMagoDoc::view() const
 {
    return mainView()->view(); //FIXME!!
 }
 
-bool KMagoDoc::openNew() 
+bool KMagoDoc::openNew()
 {
    QString filename = tempFile();
    return open(filename, true);
 }
 
-bool KMagoDoc::openLastUsed() 
+bool KMagoDoc::openLastUsed()
 {
    kdDebug(D_INI) << name() << ": open last used doc " << _lastUsed << endl;
    if (_lastUsed.isEmpty())
@@ -129,7 +135,7 @@ bool KMagoDoc::open(const QString &filename, bool tmpDoc)
    return true;
 }
 
-bool KMagoDoc::saveAs(const QString &f) 
+bool KMagoDoc::saveAs(const QString &f)
 {
    QFileInfo fileInfo(f);
    QString filename = fileInfo.absFilePath();
@@ -137,7 +143,7 @@ bool KMagoDoc::saveAs(const QString &f)
    if (filename.isEmpty() || filename == manager().fileName())
       return false;
    //QFile f(fileInfo.absFilePath());
-   if (manager().save(filename)) 
+   if (manager().save(filename))
    {
       if (isTmp())
 	 QDir::current().remove(oldfile);
@@ -151,7 +157,7 @@ bool KMagoDoc::saveAs(const QString &f)
    return false;
 }
 
-void KMagoDoc::close() 
+void KMagoDoc::close()
 {
    kdDebug(D_INI) << name() << ": close doc" << endl;
    if (isClosed())
@@ -161,7 +167,7 @@ void KMagoDoc::close()
    setCurrentManager(KTManager::null());
    view()->managerView()->clear();
    view()->transferView()->clear();
-   
+
    manager().setCallback(0);
    manager().kill(true);
    if (manager().isModified())
@@ -171,7 +177,7 @@ void KMagoDoc::close()
 
    if (isTmp())
       QDir::current().remove(oldfile);
-}  
+}
 
 void KMagoDoc::start()
 {
@@ -180,7 +186,7 @@ void KMagoDoc::start()
    _timerSave.start(_cfg_saveTime*1000, false);
 }
 
-void KMagoDoc::saveConfig(KConfig *config) 
+void KMagoDoc::saveConfig(KConfig *config)
 {
    kdDebug(D_INI) << name() << ": save config" << endl;
    config->writeEntry("Open Flags", _cfg_openFlags);
@@ -188,23 +194,27 @@ void KMagoDoc::saveConfig(KConfig *config)
    config->writeEntry("Save Time", _cfg_saveTime);
    config->writeEntry("Transfer Start Time", _cfg_TStartTime);
    config->writeEntry("Expert Mode", _cfg_expertMode);
-   config->writeEntry("ExitOnIdle", _cfg_exitOnIdle);
+   //config->writeEntry("ExitOnIdle", _cfg_exitOnIdle);
    config->writeEntry("Start Mode", _cfg_startMode);
    config->writeEntry("Load Last Doc", _cfg_loadLastDoc);
    config->writeEntry("List On Drop", _cfg_listOnDrop);
+   config->writeEntry("EnableNotify", _cfg_enableNotify);
+   config->writeEntry("AutoProgress", _cfg_autoProgress);
+   config->writeEntry("TrayProgress", _cfg_trayProgress);
+   config->writeEntry("CommandOnIdle", _cfg_commandOnIdle);
    if (!_lastUsed.isEmpty())
       config->writeEntry("Last Used Document", _lastUsed);
-   if (!isUniqueApp())
+   if (!isSingleDoc())
       mainView()->fileOpenRecent->saveEntries(config, "Recent Files");
    mainView()->managerAddRecent->saveEntries(config, "Recent Transfers");
 }
 
-void KMagoDoc::readConfig(KConfig* config) 
+void KMagoDoc::readConfig(KConfig* config)
 {
    kdDebug(D_INI) << name() << ": read config" << endl;
    _cfg_openFlags = config->readNumEntry("Open Flags", 0);
    _cfg_expertMode = config->readBoolEntry("Expert Mode", false);
-   _cfg_exitOnIdle = config->readBoolEntry("ExitOnIdle", false);
+   //_cfg_exitOnIdle = false; //config->readBoolEntry("ExitOnIdle", false);
    _cfg_updateTime = config->readNumEntry("Update Time", 2000);
    _cfg_saveTime = config->readNumEntry("Save Time", 10);
    _cfg_TStartTime = config->readNumEntry("Transfer Start Time", 2000);
@@ -212,12 +222,16 @@ void KMagoDoc::readConfig(KConfig* config)
    _cfg_loadLastDoc = config->readBoolEntry("Load Last Doc", true);
    _cfg_listOnDrop = config->readBoolEntry("List On Drop", false);
    _lastUsed = config->readEntry("Last Used Document", "");
-   if (!isUniqueApp())
+   _cfg_enableNotify = config->readBoolEntry("EnableNotify", true);
+   _cfg_autoProgress = config->readBoolEntry("AutoProgress", false);
+   _cfg_trayProgress = config->readBoolEntry("TrayProgress", false);
+   _cfg_commandOnIdle = config->readEntry("CommandOnIdle", "");
+   if (!isSingleDoc())
       mainView()->fileOpenRecent->loadEntries(config, "Recent Files");
    mainView()->managerAddRecent->loadEntries(config, "Recent Transfers");
 }
 
-void KMagoDoc::loadState(bool restored) 
+void KMagoDoc::loadState(bool restored)
 {
    kdDebug(D_INI) << name() << ": loadState " << restored << endl;
    KConfig * config = kapp->config();
@@ -225,7 +239,7 @@ void KMagoDoc::loadState(bool restored)
    config->setGroup("Configuration");
    readConfig(config);
    // if this window is not being restored
-   if (!restored) 
+   if (!restored)
    {
       mainView()->applySettings(config, false);
       view()->initView();
@@ -233,7 +247,7 @@ void KMagoDoc::loadState(bool restored)
    config->setGroup(grp);
 }
 
-void KMagoDoc::saveState() 
+void KMagoDoc::saveState()
 {
    KConfig * config = kapp->config();
    QString grp = config->group();
@@ -243,7 +257,7 @@ void KMagoDoc::saveState()
    config->setGroup(grp);
 }
 
-void KMagoDoc::reloadState() 
+void KMagoDoc::reloadState()
 {
    QListIterator<KMainWindow> it(*KMainWindow::memberList);
    for (it.toFirst(); it.current(); ++it)
@@ -252,7 +266,7 @@ void KMagoDoc::reloadState()
    }
 }
 
-int KMagoDoc::isDuplicate(const KURL &rmt, const KURL &lcl) 
+int KMagoDoc::isDuplicate(const KURL &rmt, const KURL &lcl)
 {
    for (KCntIterator itm(manager()); !itm.current().isNull(); ++itm)
    {
@@ -267,9 +281,9 @@ int KMagoDoc::isDuplicate(const KURL &rmt, const KURL &lcl)
       }
    }
    return 0;
-} 
+}
 
-void KMagoDoc::addTransfer(const KURL &u, KTManager mngr) 
+void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
 {
    if (mngr.isNull())
       mngr = currentManager();
@@ -281,21 +295,21 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
        && !KDlgOpenTransfer::getOpenTransfer(this, mngr, rmt, lcl, type))
       return;
    KTransfer glb = mngr.findGlobal(type).toTransfer();
-   if (glb.isNull()) 
+   if (glb.isNull())
    {
       KMessageBox::sorry(mainWindow(),
 			 i18n("Transfer Type not acceptable"),
 			 i18n("transfer type not acceptable"), false);
       return;
    }
-   if (!glb.isProtocolSupported(rmt.protocol())) 
+   if (!glb.isProtocolSupported(rmt.protocol()))
    {
       KMessageBox::sorry(mainWindow(),
 			 i18n("Protocol " + rmt.protocol() + " not supported"),
 			 i18n("protocol not supported"), false);
       return;
    }
-   if (lcl.path().isEmpty() || QFileInfo(lcl.path()).isDir()) 
+   if (lcl.path().isEmpty() || QFileInfo(lcl.path()).isDir())
    {
       KMessageBox::sorry(mainWindow(),
 			 i18n("File " + lcl.path() + " not acceptable"),
@@ -305,7 +319,7 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
    // check for a transfer with these file or url
    int chk = isDuplicate(rmt, lcl);
    if (chk)
-      switch (chk) 
+      switch (chk)
       {
       case 1:
 	 KMessageBox::sorry(mainWindow(),
@@ -322,12 +336,12 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
    QString file, tmpfile;
    file = lcl.path();
    tmpfile = glb.getTempFile(rmt, lcl).path();
-   if (QDir::current().exists(file)) 
+   if (QDir::current().exists(file))
    {
-      if (QDir::current().exists(tmpfile) && file != tmpfile) 
+      if (QDir::current().exists(tmpfile) && file != tmpfile)
       {
 	 // either tmpfile and file exists
-	 switch (promptFilesToRecover(file, tmpfile)) 
+	 switch (promptFilesToRecover(file, tmpfile))
 	 {
 	 case KMessageBox::Ok: // recover file
 	    QDir::current().remove(tmpfile);
@@ -345,11 +359,11 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
 	 default: // cancel operation
 	    kdFatal(D_RUN) << name() << ": addTransfer PROMPT ERROR" << endl;
 	 } // end switch
-      } 
-      else 
+      }
+      else
       { // tmpfile not exists
 	 // recover file
-	 switch (promptFileToRecover(file)) 
+	 switch (promptFileToRecover(file))
 	 {
 	 case KMessageBox::Yes: // recover file
 	    QDir::current().rename(file, tmpfile);
@@ -364,12 +378,12 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
 	 }
       } // end else
    }
-   else 
+   else
    { // file don't exists
-      if (QDir::current().exists(tmpfile)) 
+      if (QDir::current().exists(tmpfile))
       {
 	 // recover tmpfile
-	 switch (promptFileToRecover(tmpfile)) 
+	 switch (promptFileToRecover(tmpfile))
 	 {
 	 case KMessageBox::Yes: // recover file
 	    break;
@@ -385,10 +399,10 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
    } // end else
    // evaluting start mode
    int start = getStartMode();
-   if (start == START_PROMPT) 
+   if (start == START_PROMPT)
    {
       switch (promptStartMode(i18n("Select a start mode"),
-			      i18n("Transfer:\n" + rmt.url() + "\nto " + file))) 
+			      i18n("Transfer:\n") + rmt.url() + i18n("\nto ") + file))
       {
       case KMessageBox::Yes:
 	 start = START_NOW;
@@ -402,48 +416,53 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
 	 kdFatal(D_INI) << name() << ": addTransfer PROMPT ERROR" << endl;
       }
    }
-   // add transfer	
+   // add transfer
    mainView()->managerAddRecent->addURL(rmt);
    KTransfer t = mngr.itemNew(type, rmt, lcl);
    if (start == START_NOW)
       t.start();
 }
 
-void KMagoDoc::setUpdateTime(int u) 
+void KMagoDoc::setUpdateTime(int u)
 {
-   if (_cfg_updateTime != u) 
+   if (_cfg_updateTime != u)
    {
       _cfg_updateTime = u;
       _timerUpd.changeInterval(u);
    }
 }
 
-void KMagoDoc::setSaveTime(int u) 
+void KMagoDoc::setSaveTime(int u)
 {
-   if (_cfg_saveTime != u) 
+   if (_cfg_saveTime != u)
    {
       _cfg_saveTime = u;
       _timerSave.changeInterval(u*1000);
    }
 }
 
-void KMagoDoc::setTransferStartTime(int t) 
-{ 
+void KMagoDoc::setTransferStartTime(int t)
+{
    if (_cfg_TStartTime != t)
    {
-      _cfg_TStartTime = t; 
+      _cfg_TStartTime = t;
       _timerTStart.changeInterval(t);
    }
 }
 
 void KMagoDoc::setExitOnIdle(bool l)
 {
-   _cfg_exitOnIdle = l;
+   _exitOnIdle = l;
+}
+
+void KMagoDoc::setExecuteOnIdle(bool v)
+{
+   _executeOnIdle = v;
 }
 
 //////////////////////////////
 
-void KMagoDoc::setCurrentManager(KTManager m) 
+void KMagoDoc::setCurrentManager(KTManager m)
 {
    if (m == currentManager())
       return;
@@ -467,14 +486,14 @@ void KMagoDoc::setCurrentManager(KTManager m)
       setCurrentTransfer(*t);
 }
 
-void KMagoDoc::setCurrentTransfer(KTransfer t) 
+void KMagoDoc::setCurrentTransfer(KTransfer t)
 {
    if (t == currentTransfer())
       return;
    _currentTransfer = t;
    kdDebug(D_VIE) << name() << ": current transfer " << (t.isNull() ? "NULL" : t.name()) << endl;
    // update main view
-   if (!t.isNull()) 
+   if (!t.isNull())
    {
       mainView()->slotStatusMsg(t.remote().prettyURL() + " -> " + t.local().fileName());
       //slotDocTransferStateChange(t);
@@ -485,8 +504,8 @@ void KMagoDoc::setCurrentTransfer(KTransfer t)
 	 _curTransferDict.insert(t.container().id(), i);
       }
       *i = t;
-   } 
-   else 
+   }
+   else
    {
       mainView()->slotStatusMsg(i18n(KMagoApp::IDS_STATUS_DEFAULT));
    }
@@ -495,13 +514,13 @@ void KMagoDoc::setCurrentTransfer(KTransfer t)
    view()->transferView()->itemSelect(t);
 }
 
-void KMagoDoc::resetView() 
+void KMagoDoc::resetView()
 {
    // reset object's mods
    for(KCntIterator it(manager()); !it.current().isNull(); ++it)
    {
       it.current().resetMods();
-      for (KCntIterator itt(it.current().toTManager()); !itt.current().isNull(); 
+      for (KCntIterator itt(it.current().toTManager()); !itt.current().isNull();
 	   ++itt)
 	 itt.current().resetMods();
    }
@@ -509,7 +528,7 @@ void KMagoDoc::resetView()
    // reset current transfer dictionary
    _curTransferDict.clear();
 
-   mainView()->fileDownloadLock->setChecked(manager().downloadLock());
+   mainView()->setDownloadLock(manager().downloadLock());
    mainView()->updateManagerList();
    _currentManager.setNull();
    view()->reset();
@@ -520,7 +539,7 @@ void KMagoDoc::resetView()
 
 void KMagoDoc::updateView(KObject obj)
 {
-   if (obj.isNull()) 
+   if (obj.isNull())
    {
       kdWarning(D_VIE) << name() << ": updateView on null object" << endl;
       return;
@@ -537,21 +556,36 @@ void KMagoDoc::updateView(KObject obj)
       bugrep->appendLine(obj.message());
       bugrep->show();
    }
+   if (!_firstIdle && (!manager().isIdle() || !executeOnIdle()))
+      _firstIdle = true;
    switch (obj.type())
    {
    case TYP_MMANAGER:
       if (obj.isMod(MDI_MMN_IDLE))
       {
-	 // if is idle and exitOnIdle is true, exit
-	 if (getExitOnIdle() && manager().isIdle())
+	 if (manager().isIdle() && executeOnIdle() && _firstIdle
+	     && !getCommandOnIdle().isEmpty())
 	 {
+	    kdDebug(D_RUN) << name() << ": execute cmd on idle: " << getCommandOnIdle() << endl;
+	    KShellProcess sh;
+	    QStringList lst = QStringList::split(" ", getCommandOnIdle());
+	    for (QStringList::Iterator it = lst.begin(); it != lst.end(); ++it)
+	       sh << *it;
+	    sh.start(KProcess::DontCare, KProcess::NoCommunication);
+	    _firstIdle = false;
+	 }
+	 // if is idle and exitOnIdle is true, exit
+	 if (exitOnIdle() && manager().isIdle())
+	 {
+	    if (getEnableNotify())
+	       KNotifyClient::event("appQuit", i18n("Application quit"));
 	    QTimer::singleShot(1000, mainView(), SLOT(slotFileClose()));
 	 }
       }
       if (obj.isMod(MDI_MMN_DLOCK))
 	 // changed lock download
 	 ;
-      else if (obj.isMod(MDI_CNT))
+      if (obj.isMod(MDI_CNT))
       {
 	 // added or removed a tmanager
 	 mainView()->updateManagerList();
@@ -563,7 +597,10 @@ void KMagoDoc::updateView(KObject obj)
       }
       if (obj.isMod(MDI_ACTCNT))
       {
+	 mainView()->killAll->setEnabled(manager().isRunning());
       }
+      if ((obj.isMod(MDI_STOP) || obj.isMod(MDI_START)) && mainView()->sysTray())
+	 mainView()->sysTray()->updateIcon();
       if (obj.isMod(MDI_BAND))
       {
 	 // global band changed
@@ -647,8 +684,25 @@ void KMagoDoc::updateView(KObject obj)
       break;
    case TYP_TWGET:
    case TYP_TKIO:
+      if (obj.isMod(MDI_START))
+      {
+	 if (getEnableNotify())
+	    KNotifyClient::event("transferStart", i18n("transfer start: ") + obj.toTransfer().remote().prettyURL());
+	 if (getAutoProgress() && mainView()->_progressWnds[obj.id()] == 0)
+	    mainView()->openTransferProgress(obj.toTransfer());
+      }
+      if (obj.isMod(MDI_STOP))
+      {
+	 if (getEnableNotify() && obj.toTransfer().state() == TRN_END_ERROR)
+	    KNotifyClient::event("transferError", i18n("transfer error: ") + obj.toTransfer().remote().prettyURL());
+	 if (getEnableNotify() && obj.toTransfer().isComplete())
+	    KNotifyClient::event("transferComplete", i18n("transfer complete: ") + obj.toTransfer().remote().prettyURL());
+	 if (getAutoProgress() && obj.toTransfer().isComplete()
+	     && mainView()->_progressWnds[obj.id()] != 0)
+	    mainView()->_progressWnds[obj.id()]->close();
+      }
       if (obj.container() == currentManager())
-      { 
+      {
 	 // if transfer is in current manager
 	 if (obj.isMod(MDI_ADD))
 	 {
@@ -656,7 +710,7 @@ void KMagoDoc::updateView(KObject obj)
 	    view()->transferView()->itemAdd(obj);
 	    mainView()->updateTransferMenu();
 	    break;
-	 } 
+	 }
 	 else if (obj.isMod(MDI_REMOVE))
 	 { // removed a transfer from current manager
 	    KObject prev;
@@ -674,7 +728,11 @@ void KMagoDoc::updateView(KObject obj)
 	    obj.deleteInstance();
 	    break;
 	 }
-	 else if (obj.isMod(MDI_START) || obj.isMod(MDI_STOP))
+	 else if (obj.isMod(MDI_START))
+	 {
+	    mainView()->updateTransferMenu();
+	 }
+	 else if (obj.isMod(MDI_STOP))
 	 {
 	    mainView()->updateTransferMenu();
 	 }
@@ -716,7 +774,7 @@ bool KMagoDoc::event(QEvent *event)
 
 /////////////////////////////////////////////////////////////////////////
 
-void KMagoDoc::slotTransferStart() 
+void KMagoDoc::slotTransferStart()
 {
    //kdDebug(D_VIE) << name() << ": slotTransferStart" << endl;
    if (isClosed())
