@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.17 $
+    revision             : $Revision: 1.20 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,14 +41,14 @@
  *
  * @author Sergio Moretti
  *
- * @version $Id: kmagodoc.h,v 1.17 2001/03/23 17:14:59 sergio Exp $
+ * @version $Id: kmagodoc.h,v 1.20 2001/04/04 18:06:04 sergio Exp $
  */
 
-class KMagoBugReport : public KBugReport 
+class KMagoBugReport : public KBugReport
 {
    Q_OBJECT
 public:
-   KMagoBugReport(QWidget * parent = 0L, bool modal=true, 
+   KMagoBugReport(QWidget * parent = 0L, bool modal=true,
 		  const KAboutData *aboutData = 0L);
    void appendLine(const QString &line);
 };
@@ -56,7 +56,7 @@ public:
 class DocEvent : public QEvent
 {
 public:
-   DocEvent(KObject obj) 
+   DocEvent(KObject obj)
       : QEvent(QEvent::User), _obj(obj) {}
    KObject obj() const { return _obj; }
 private:
@@ -66,28 +66,28 @@ private:
 class KMagoApp;
 class KMagoView;
 
-/**	
+/**
  * @short KMagoDoc provides a document object for a document-view model.
  *
  * @author Sergio Moretti
- * 
- * @version $Id: kmagodoc.h,v 1.17 2001/03/23 17:14:59 sergio Exp $
  *
- * The KMagoDoc class provides a document object that can be used in 
- * conjunction with the classes KMagoApp and KMagoView to create a 
- * document-view model for standard KDE applications based on KApplication 
- * and KTMainWindow. Thereby, the document object is created by the KMagoApp 
- * instance and contains the document structure with the according methods for 
- * manipulation of the document data by KMagoView objects. Also, KMagoDoc 
- * contains the methods for serialization of the document data from and to 
+ * @version $Id: kmagodoc.h,v 1.20 2001/04/04 18:06:04 sergio Exp $
+ *
+ * The KMagoDoc class provides a document object that can be used in
+ * conjunction with the classes KMagoApp and KMagoView to create a
+ * document-view model for standard KDE applications based on KApplication
+ * and KTMainWindow. Thereby, the document object is created by the KMagoApp
+ * instance and contains the document structure with the according methods for
+ * manipulation of the document data by KMagoView objects. Also, KMagoDoc
+ * contains the methods for serialization of the document data from and to
  * files.
  */
 
-class KMagoDoc : public QObject 
+class KMagoDoc : public QObject
 {
    Q_OBJECT
 
-   class NotifyChange : public KNotifyChange 
+   class NotifyChange : public KNotifyChange
    {
    public:
       NotifyChange(KMagoDoc *doc) : _doc(doc) {}
@@ -98,7 +98,7 @@ class KMagoDoc : public QObject
    };
 
    friend class NotifyChange;
-  
+
 public:
    /** Constructor for the fileclass of the application */
    KMagoDoc(KMagoApp *parent, const char *name=0);
@@ -118,7 +118,7 @@ public:
    bool isClosed() const { return _manager.isNull(); }
    bool isTmp() const { return _tmp; }
    int isDuplicate(const KURL &rmt, const KURL &lcl);
-	  
+
    /** open a new document from a temporary file */
    bool openNew();
    /** open last used document file */
@@ -148,6 +148,14 @@ public:
    /** update the view */
    void resetView();
 
+   bool exitOnIdle() const { return _exitOnIdle; }
+   void setExitOnIdle(bool l);
+
+   bool executeOnIdle() const { return _executeOnIdle; }
+   void setExecuteOnIdle(bool v);
+
+   // configuration
+
    /** get open dialog flags */
    int getOpenFlags() const { return _cfg_openFlags; }
    /** set open dialog flags */
@@ -166,8 +174,14 @@ public:
    void setLoadLastDoc(bool l) { _cfg_loadLastDoc = l; }
    bool getListOnDrop() const { return _cfg_listOnDrop; }
    void setListOnDrop(bool l) { _cfg_listOnDrop = l; }
-   bool getExitOnIdle() const { return _cfg_exitOnIdle; }
-   void setExitOnIdle(bool l);
+   bool getEnableNotify() const { return _cfg_enableNotify; }
+   void setEnableNotify(bool s) { _cfg_enableNotify = s; }
+   bool getAutoProgress() const { return _cfg_autoProgress; }
+   void setAutoProgress(bool s) { _cfg_autoProgress = s; }
+   bool getTrayProgress() const { return _cfg_trayProgress; }
+   void setTrayProgress(bool s) { _cfg_trayProgress = s; }
+   QString getCommandOnIdle() const { return _cfg_commandOnIdle; }
+   void setCommandOnIdle(const QString &s) { _cfg_commandOnIdle = s; }
 
    /** read state from config object */
    void readConfig(KConfig *config);
@@ -219,17 +233,21 @@ private:
    bool _tmp;
    /** last open document file */
    QString _lastUsed;
+   /** exit on idle: exit app if no transfers are left to run */
+   bool _exitOnIdle;
+   /** mark first idle state, to call commandOnIdle */
+   bool _firstIdle;
+   /** enable/disable running of commandOnIdle when app reach first idle state */
+   bool _executeOnIdle;
 
    QIntDict<KTransfer> _curTransferDict;
 
    // configuration
-  
+
    /** flags to control open dialog */
    int _cfg_openFlags;
    /** expert mode: don't prompt for delete operation*/
    bool _cfg_expertMode;
-   /** exit on idle: exit app if no transfers are left to run */
-   bool _cfg_exitOnIdle;
    /** update display time */
    int _cfg_updateTime;
    /** time interval between transfer startings */
@@ -242,6 +260,14 @@ private:
    bool _cfg_loadLastDoc;
    /** open popup menu with managers list on drop */
    bool _cfg_listOnDrop;
+   /** enable event notification */
+   bool _cfg_enableNotify;
+   /** automatic opening and closing of transfer's progress windows */
+   bool _cfg_autoProgress;
+   /** add system tray icon to progress window */
+   bool _cfg_trayProgress;
+   /** command to execute when first idle state is reached */
+   QString _cfg_commandOnIdle;
 };
 
 #endif // KMAGODOC_H
