@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.27 $
+    revision             : $Revision: 1.28 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,14 +27,14 @@
 #include "kmagodoc.h"
 
 
-KMagoView::KMagoView(KMagoDoc *doc, QWidget *parent, const char *name) 
-   : QSplitter(parent, name), _doc(doc), _managerView(0), _transferView(0) 
+KMagoView::KMagoView(KMagoDoc *doc, QWidget *parent, const char *name)
+   : QSplitter(parent, name), _doc(doc), _managerView(0), _transferView(0)
 {
    //FIXME!! all the manager's views are created now, and only one is showed,
    //FIXME!! this is not a clean way to go, but destroying and re-creating views
    //FIXME!! brings problems on attributes-restoring
    _miv = new KMManagerIconView(doc->manager(), doc,
-				&KMagoView::slotSetCurrentManager, this, 
+				&KMagoView::slotSetCurrentManager, this,
 				QString("%1-miconview").arg(name));
    setResizeMode(_miv, Stretch);
    _mlv = new KMManagerListView(doc->manager(), doc,
@@ -42,31 +42,31 @@ KMagoView::KMagoView(KMagoDoc *doc, QWidget *parent, const char *name)
 				QString("%1-mlistview").arg(name));
    setResizeMode(_mlv, Stretch);
    _mlv->hide();
-   
+
    _managerView = dynamic_cast<KContainerView*>(_miv);
 
-   _transferView = new KTManagerListView(doc, 
-					 &KMagoView::slotSetCurrentTransfer, 
+   _transferView = new KTManagerListView(doc,
+					 &KMagoView::slotSetCurrentTransfer,
 					 this, QString("%1-tview").arg(name));
    setResizeMode(dynamic_cast<QWidget*>(_transferView), Stretch);
 
    initActions();
 }
 
-KMagoView::~KMagoView() 
+KMagoView::~KMagoView()
 {
    kdDebug(D_INI) << name() << ": destroy" << endl;
    //writeConfig();
 }
 
-void KMagoView::initMenu() 
+void KMagoView::initMenu()
 {
    // to be called after createGUI
    _managerMenu = static_cast<KPopupMenu*>(
-      doc()->mainWindow()->factory()->container("manager_popup", 
+      doc()->mainWindow()->factory()->container("manager_popup",
 						doc()->mainWindow()));
    _transferMenu = static_cast<KPopupMenu*>(
-      doc()->mainWindow()->factory()->container("transfer_popup", 
+      doc()->mainWindow()->factory()->container("transfer_popup",
 						doc()->mainWindow()));
 }
 
@@ -82,10 +82,10 @@ void KMagoView::initActions()
    _managerViewMode->setItems(lst);
    _managerViewMode->setCurrentItem(0); //FIXME save/restore settings
 
-   _orientation = 
+   _orientation =
       new KToggleAction(i18n("Vertical Orientation"),
 			0, this, SLOT(slotOrientation()),
-			doc()->mainWindow()->actionCollection(), 
+			doc()->mainWindow()->actionCollection(),
 			"split_orientation");
    _orientation->setToolTip(i18n("Set view's orientation"));
 }
@@ -127,41 +127,41 @@ void KMagoView::initView()
    transferView()->itemSelect(doc()->currentTransfer());
 }
 
-KMagoDoc * KMagoView::doc() const 
+KMagoDoc * KMagoView::doc() const
 {
    return _doc;
 }
 
-void KMagoView::reset() 
+void KMagoView::reset()
 {
    kdDebug(D_VIE) << name() << ": reset view" << endl;
    managerView()->setContainer(doc()->manager());
    transferView()->setContainer(doc()->currentManager());
 }
 
-void KMagoView::showManagers(bool on) 
-{ 
+void KMagoView::showManagers(bool on)
+{
    //bool state = _lbManager->isVisible();
    //if (state == on)
    //  return;
-   if (on) 
+   if (on)
       dynamic_cast<QWidget*>(managerView())->show();
-   else 
+   else
       dynamic_cast<QWidget*>(managerView())->hide();
 }
 
-void KMagoView::setOrientation(bool vert) 
+void KMagoView::setOrientation(bool vert)
 {
    bool state = (orientation() == Vertical);
    if (vert == state)
       return;
    managerView()->setOrientation(vert);
-   if (vert) 
+   if (vert)
    {
       QSplitter::setOrientation(Vertical);
       //_lbManager->setColumnMode(QListBox::FitToWidth);
-   }  
-   else 
+   }
+   else
    {
       QSplitter::setOrientation(Horizontal);
       //_lbManager->setColumnMode(1);
@@ -170,10 +170,15 @@ void KMagoView::setOrientation(bool vert)
 
 void KMagoView::applySettings(KConfig *config)
 {
-   _managerViewMode->setCurrentItem(config->readNumEntry("ManagerViewMode", 0));
-   _orientation->setChecked(config->readBoolEntry("Split Orientation", true));
+   _managerViewMode->setCurrentItem(config->readNumEntry("ManagerViewMode", 1));
+   _orientation->setChecked(config->readBoolEntry("Split Orientation", false));
    slotOrientation();
-   setSizes(config->readIntListEntry("Splitter Sizes"));
+   QValueList<int> lst = config->readIntListEntry("Splitter Sizes");
+   if (lst.isEmpty())
+   {
+      lst << 1 << 127 << 375;
+   }
+   setSizes(lst);
    _miv->applySettings(config);
    _mlv->applySettings(config);
    transferView()->applySettings(config);
@@ -191,7 +196,7 @@ void KMagoView::saveSettings(KConfig *config)
 
 // Slots
 
-void KMagoView::slotSetCurrentManager(KObject item) 
+void KMagoView::slotSetCurrentManager(KObject item)
 {
    //FIXME replace with direct call to setCurrentManager
    kdDebug(D_VIE) << name() << ": highlight manager " << (item.isNull() ? -1 : item.id()) << endl;
@@ -199,7 +204,7 @@ void KMagoView::slotSetCurrentManager(KObject item)
    doc()->setCurrentManager(item.toTManager());
 }
 
-void KMagoView::slotSetCurrentTransfer(KObject item) 
+void KMagoView::slotSetCurrentTransfer(KObject item)
 {
    //FIXME replace with direct call to setCurrentTransfer
    kdDebug(D_VIE) << name() << ": highlight transfer " << (item.isNull() ? -1: item.id()) << endl;
@@ -211,7 +216,7 @@ void KMagoView::slotManagerViewMode()
    initView();
 }
 
-void KMagoView::slotOrientation() 
+void KMagoView::slotOrientation()
 {
    setOrientation(_orientation->isChecked());
 }
