@@ -4,7 +4,7 @@
     begin                : Wed Dec 20 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.12 $
+    revision             : $Revision: 1.13 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,9 +23,9 @@
 #include "kmagoview.h"
 #include "ktmanagerlistview.h"
 
-KTManagerListView::KTManagerListView(KMagoDoc *doc, Callback cb, 
+KTManagerListView::KTManagerListView(KMagoDoc *doc, Callback cb,
 				     QWidget *parent, const char *name)
-   : KListView(parent, name), KContainerView(doc, cb, KContainer::null()) 
+   : KListView(parent, name), KContainerView(doc, cb, KContainer::null())
 {
    setAcceptDrops(true);
    setDragEnabled(true);
@@ -41,7 +41,7 @@ KTManagerListView::KTManagerListView(KMagoDoc *doc, Callback cb,
    connect(this, SIGNAL(selectionChanged(QListViewItem*)),
 	   this, SLOT(slotSelectionChanged(QListViewItem*)));
    connect(this, SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)),
-	   this, SLOT(slotContextMenu(KListView*, QListViewItem*, 
+	   this, SLOT(slotContextMenu(KListView*, QListViewItem*,
 				      const QPoint&)));
    // init actions
    initActions();
@@ -66,63 +66,63 @@ KTManagerListView::~KTManagerListView()
    kdDebug(D_INI) << name() << ": destroy" << endl;
 }
 
-void KTManagerListView::initActions() 
+void KTManagerListView::initActions()
 {
    _viewState = new KToggleAction(i18n("Show State"),
 				  0, this, SLOT(slotInitView()),
-				  doc()->mainWindow()->actionCollection(), 
+				  doc()->mainWindow()->actionCollection(),
 				  "tview_state");
    _viewURL = new KToggleAction(i18n("Show URL"),
 				0, this, SLOT(slotInitView()),
-				doc()->mainWindow()->actionCollection(), 
+				doc()->mainWindow()->actionCollection(),
 				"tview_url");
    _viewLocal = new KToggleAction(i18n("Show Local Filename"),
 				0, this, SLOT(slotInitView()),
-				doc()->mainWindow()->actionCollection(), 
+				doc()->mainWindow()->actionCollection(),
 				"tview_local");
    _viewResuming = new KToggleAction(i18n("Show Resuming"),
 				     0, this, SLOT(slotInitView()),
-				     doc()->mainWindow()->actionCollection(), 
+				     doc()->mainWindow()->actionCollection(),
 				     "tview_resuming");
    _viewPercent = new KToggleAction(i18n("Show Percent"),
 				    0, this, SLOT(slotInitView()),
-				    doc()->mainWindow()->actionCollection(), 
+				    doc()->mainWindow()->actionCollection(),
 				  "tview_percent");
    _viewTime = new KToggleAction(i18n("Show Est.Time"),
 				  0, this, SLOT(slotInitView()),
-				  doc()->mainWindow()->actionCollection(), 
+				  doc()->mainWindow()->actionCollection(),
 				  "tview_time");
    _viewPartial = new KToggleAction(i18n("Show Partial"),
 				    0, this, SLOT(slotInitView()),
-				    doc()->mainWindow()->actionCollection(), 
+				    doc()->mainWindow()->actionCollection(),
 				    "tview_partial");
    _viewLen = new KToggleAction(i18n("Show Length"),
 				0, this, SLOT(slotInitView()),
-				doc()->mainWindow()->actionCollection(), 
+				doc()->mainWindow()->actionCollection(),
 				"tview_len");
    _viewBand = new KToggleAction(i18n("Show Bandwidth"),
 				 0, this, SLOT(slotInitView()),
-				 doc()->mainWindow()->actionCollection(), 
+				 doc()->mainWindow()->actionCollection(),
 				 "tview_band");
    _viewMBand = new KToggleAction(i18n("Show Medium Bandwidth"),
 				  0, this, SLOT(slotInitView()),
-				  doc()->mainWindow()->actionCollection(), 
+				  doc()->mainWindow()->actionCollection(),
 				  "tview_mband");
    _viewPriority = new KToggleAction(i18n("Show Priority"),
 				     0, this, SLOT(slotInitView()),
-				     doc()->mainWindow()->actionCollection(), 
+				     doc()->mainWindow()->actionCollection(),
 				     "tview_priority");
    _viewID = new KToggleAction(i18n("Show ID"),
 			       0, this, SLOT(slotInitView()),
-			       doc()->mainWindow()->actionCollection(), 
+			       doc()->mainWindow()->actionCollection(),
 			       "tview_id");
    _viewType = new KToggleAction(i18n("Show Type"),
 				 0, this, SLOT(slotInitView()),
-				 doc()->mainWindow()->actionCollection(), 
+				 doc()->mainWindow()->actionCollection(),
 				 "tview_type");
    _viewError = new KToggleAction(i18n("Show Error"),
 				 0, this, SLOT(slotInitView()),
-				 doc()->mainWindow()->actionCollection(), 
+				 doc()->mainWindow()->actionCollection(),
 				 "tview_error");
    _viewStateStr = new KToggleAction(i18n("Show State String"),
 					  0, this, SLOT(slotShowStateStr()),
@@ -130,7 +130,7 @@ void KTManagerListView::initActions()
 					  "tview_statestr");
 }
 
-void KTManagerListView::initView() 
+void KTManagerListView::initView()
 {
    while (columns())
       removeColumn(0);
@@ -230,7 +230,7 @@ void KTManagerListView::setSortBy(ModIndex p, bool increasing)
    _sortDir = increasing;
 }
 
-QDragObject * KTManagerListView::dragObject() const 
+QDragObject * KTManagerListView::dragObject() const
 {
    KTransfer item = doc()->currentTransfer();
    if (!transferDragEnabled(item))
@@ -248,14 +248,14 @@ QDragObject * KTManagerListView::dragObject() const
    return drag;
 }
 
-bool KTManagerListView::acceptDrag(QDropEvent *event) const 
+bool KTManagerListView::acceptDrag(QDropEvent *event) const
 {
    //kdDebug(D_RUN) << name() << ": acceptDrag " << (source ? source->container().name() : QString::null) << " -> " << container().name() << endl;
    return (KContainerView::acceptDrop(event, container())
 	   && transferCanDecode(event));
 }
 
-KTManagerListItem * KTManagerListView::itemFind(KObject item) const 
+KTManagerListItem * KTManagerListView::itemFind(KObject item) const
 {
    kdFatal(item.isNull(), D_VIE) << name() << ": find null item" << endl;
    KTManagerListItem *i;
@@ -292,17 +292,17 @@ KObject KTManagerListView::itemAbove(KObject item) const
    return b->transfer();
 }
 
-void KTManagerListView::itemAdd(KObject item) 
+void KTManagerListView::itemAdd(KObject item)
 {
    new KTManagerListItem(this, item.toTransfer());
 }
 
-void KTManagerListView::itemRemove(KObject item) 
+void KTManagerListView::itemRemove(KObject item)
 {
    delete itemFind(item);
 }
 
-void KTManagerListView::itemSelect(KObject item) 
+void KTManagerListView::itemSelect(KObject item)
 {
    if (item.isNull())
       clearSelection();
@@ -310,7 +310,7 @@ void KTManagerListView::itemSelect(KObject item)
       setSelected(itemFind(item), true);
 }
 
-void KTManagerListView::itemUpdate(KObject item) 
+void KTManagerListView::itemUpdate(KObject item)
 {
    if (item.isMod(sortBy()))
    {
@@ -328,7 +328,7 @@ void KTManagerListView::itemUpdate(KObject item)
    }
 }
 
-void KTManagerListView::itemUpdateText(KObject item) 
+void KTManagerListView::itemUpdateText(KObject item)
 {
    if (item.isMod(sortBy()))
    {
@@ -345,36 +345,36 @@ void KTManagerListView::itemUpdateText(KObject item)
    }
 }
 
-int KTManagerListView::column(int i) const 
+int KTManagerListView::column(int i) const
 {
    return _columnMap[i];
 }
 
-void KTManagerListView::applySettings(KConfig *config) 
+void KTManagerListView::applySettings(KConfig *config)
 {
    _viewState->setChecked(config->readBoolEntry("TManagerListView State", true));
    _viewURL->setChecked(config->readBoolEntry("TManagerListView URL", true));
    _viewLocal->setChecked(config->readBoolEntry("TManagerListView Local", true));
-   _viewResuming->setChecked(config->readBoolEntry("TManagerListView Resuming", 
+   _viewResuming->setChecked(config->readBoolEntry("TManagerListView Resuming",
 						   true));
-   _viewPercent->setChecked(config->readBoolEntry("TManagerListView Percent", 
+   _viewPercent->setChecked(config->readBoolEntry("TManagerListView Percent",
 						  true));
    _viewTime->setChecked(config->readBoolEntry("TManagerListView Time", true));
-   _viewPartial->setChecked(config->readBoolEntry("TManagerListView Partial", 
+   _viewPartial->setChecked(config->readBoolEntry("TManagerListView Partial",
 						  true));
    _viewLen->setChecked(config->readBoolEntry("TManagerListView Len", true));
    _viewBand->setChecked(config->readBoolEntry("TManagerListView Band", true));
    _viewMBand->setChecked(config->readBoolEntry("TManagerListView MBand", true));
-   _viewPriority->setChecked(config->readBoolEntry("TManagerListView Priority", 
+   _viewPriority->setChecked(config->readBoolEntry("TManagerListView Priority",
 						   true));
    _viewType->setChecked(config->readBoolEntry("TManagerListView Type", true));
    _viewID->setChecked(config->readBoolEntry("TManagerListView ID", true));
    _viewError->setChecked(config->readBoolEntry("TManagerListView Error", true));
-   _viewStateStr->setChecked(config->readBoolEntry("TManagerListView StateStr", 
+   _viewStateStr->setChecked(config->readBoolEntry("TManagerListView StateStr",
 	 					   true));
    _sortByCol = config->readNumEntry("TManagerListView SortBy", 0);
    _sortDir = config->readBoolEntry("TManagerListView SortDir", true);
-}   
+}
 
 void KTManagerListView::saveSettings(KConfig *config)
 {
@@ -399,18 +399,18 @@ void KTManagerListView::saveSettings(KConfig *config)
 
 // slots
 
-void KTManagerListView::slotDropped(QDropEvent *event, QListViewItem *) 
+void KTManagerListView::slotDropped(QDropEvent *event, QListViewItem *)
 {
    dropTransferList(event, doc(), container());
 }
 /*
-void KTManagerListView::slotExecuted(QListViewItem *) 
+void KTManagerListView::slotExecuted(QListViewItem *)
 {
   mainView()->slotTransferStatus();
 }
 */
 void KTManagerListView::slotContextMenu(KListView *, QListViewItem *i,
-					const QPoint &p) 
+					const QPoint &p)
 {
    if (i == 0)
       return;
@@ -418,7 +418,7 @@ void KTManagerListView::slotContextMenu(KListView *, QListViewItem *i,
    view()->transferMenu()->popup(p);
 }
 
-void KTManagerListView::slotSelectionChanged(QListViewItem * item) 
+void KTManagerListView::slotSelectionChanged(QListViewItem * item)
 {
    //emit sigSelectionChanged(dynamic_cast<KTManagerListItem*>(item)->transfer());
    itemSelectionChanged(dynamic_cast<KTManagerListItem*>(item)->transfer());
@@ -428,7 +428,7 @@ void KTManagerListView::slotInitView()
 {
    initView();
    reset();
-}   
+}
 
 void KTManagerListView::slotShowStateStr()
 {
@@ -438,12 +438,12 @@ void KTManagerListView::slotShowStateStr()
 /////////////////////////////////////////////////////////////////////
 
 KTManagerListItem::KTManagerListItem(KListView *parent, KTransfer tr)
-   : QListViewItem(parent), t(tr) 
+   : QListViewItem(parent), t(tr)
 {
    update();
 }
 
-QString KTManagerListItem::text(int column) const 
+QString KTManagerListItem::text(int column) const
 {
    // this check is needed when a clear operation is done on container, as
    // all objects still visibles are destroyed
@@ -453,12 +453,12 @@ QString KTManagerListItem::text(int column) const
       return QString::null;
    }
    KTManagerListView * view = dynamic_cast<KTManagerListView*>(listView());
-   switch (view->column(column)) 
+   switch (view->column(column))
    {
       //#ifndef NTEST
       //  case 0: return QString("%1").arg(t.status(), 5, 16);
       //#else
-   case 0: 
+   case 0:
       if (view->showStateStr())
 	 return t.stateStr();
       return QString::null;
@@ -470,7 +470,7 @@ QString KTManagerListItem::text(int column) const
    case 3:
       return QString("%1:%2").arg(t.resumeStr()).arg(t.resumed());
    case 4:
-      return QString("%1").arg(t.len() ? 100*t.partial()/t.len() : 0, 3);
+      return QString("%1").arg(t.percent(), 3);
    case 5:
       return t.estTime().toString();
    case 6:
@@ -495,7 +495,7 @@ QString KTManagerListItem::text(int column) const
    return "";
 }
 
-QString KTManagerListItem::key(int column, bool) const 
+QString KTManagerListItem::key(int column, bool) const
 {
    if (t.isNull())
    {
@@ -503,7 +503,7 @@ QString KTManagerListItem::key(int column, bool) const
       return QString::null;
    }
    KTManagerListView * view = dynamic_cast<KTManagerListView*>(listView());
-   switch (view->column(column)) 
+   switch (view->column(column))
    {
    case 1:
    case 2:
@@ -532,19 +532,19 @@ QString KTManagerListItem::key(int column, bool) const
    return "";
 }
 
-void KTManagerListItem::update() 
+void KTManagerListItem::update()
 {
    if (t.isNull())
    {
       //kdWarning(D_VIE) << ": KTManagerListItem::update on null item" << endl;
       return;
    }
-   if (t.isComplete()) 
+   if (t.isComplete())
    {
       setPixmap(0, SmallIcon("player_eject"));
       return;
    }
-   switch (t.state()) 
+   switch (t.state())
    {
    case TRN_READY:
    case TRN_END_READY:
