@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.25 $
+    revision             : $Revision: 1.26 $
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,7 +21,7 @@
 #include "ktransfer.h"
 
 
-const KURL & KTransfer::local() const 
+const KURL & KTransfer::local() const
 {
    return impl()->local();
 }
@@ -31,7 +31,7 @@ void KTransfer::setLocal(const KURL &lcl) const
    impl()->setLocal(lcl);
 }
 
-const KURL & KTransfer::remote() const 
+const KURL & KTransfer::remote() const
 {
    return impl()->remote();
 }
@@ -41,7 +41,7 @@ void KTransfer::setRemote(const KURL &rmt) const
    impl()->setRemote(rmt);
 }
 
-const KURL & KTransfer::tmp() const 
+const KURL & KTransfer::tmp() const
 {
    return impl()->tmp();
 }
@@ -51,7 +51,7 @@ void KTransfer::setTmp(const KURL &tmp) const
    impl()->setTmp(tmp);
 }
 
-int KTransfer::len() const 
+int KTransfer::len() const
 {
    return impl()->len();
 }
@@ -61,12 +61,17 @@ void KTransfer::setLen(int l) const
    impl()->setLen(l);
 }
 
-int KTransfer::partial() const 
+int KTransfer::partial() const
 {
    return impl()->partial();
 }
 
-int KTransfer::resumed() const 
+int KTransfer::percent() const
+{
+   return impl()->percent();
+}
+
+int KTransfer::resumed() const
 {
    return impl()->resumed();
 }
@@ -76,57 +81,57 @@ void KTransfer::setResumed(int r) const
    impl()->setResumed(r);
 }
 
-void KTransfer::setRsmState(RsmState s) const 
+void KTransfer::setRsmState(RsmState s) const
 {
    impl()->setRsmState(s);
 }
 
-int KTransfer::retry() const 
+int KTransfer::retry() const
 {
    return impl()->retry();
 }
 
-TrnState KTransfer::state() const 
+TrnState KTransfer::state() const
 {
    return impl()->state();
 }
 
-void KTransfer::setState(TrnState s) const 
+void KTransfer::setState(TrnState s) const
 {
    impl()->setState(s);
 }
 
-RsmState KTransfer::rsmState() const 
+RsmState KTransfer::rsmState() const
 {
    return impl()->rsmState();
 }
 
-int KTransfer::bandwidth() const 
+int KTransfer::bandwidth() const
 {
    return impl()->bandwidth();
 }
 
-int KTransfer::mediumBandwidth() const 
+int KTransfer::mediumBandwidth() const
 {
    return impl()->mediumBandwidth();
 }
 
-QTime KTransfer::startTime() const 
+QTime KTransfer::startTime() const
 {
    return impl()->startTime();
 }
 
-QString KTransfer::progressStr() const 
+QString KTransfer::progressStr() const
 {
    return impl()->progressStr();
 }
 
-QString KTransfer::stateStr() const 
+QString KTransfer::stateStr() const
 {
    return impl()->stateStr();
 }
 
-QString KTransfer::stateStr(TrnState s) // static 
+QString KTransfer::stateStr(TrnState s) // static
 {
    return KTransferImpl::stateStr(s);
 }
@@ -146,22 +151,22 @@ QString KTransfer::resumeString(RsmState s) // static
    return KTransferImpl::resumeString(s);
 }
 
-bool KTransfer::isProtocolSupported(const QString &proto) const 
+bool KTransfer::isProtocolSupported(const QString &proto) const
 {
    return impl()->isProtocolSupported(proto);
 }
 
-bool KTransfer::isComplete() const 
+bool KTransfer::isComplete() const
 {
    return impl()->isComplete();
 }
 
-bool KTransfer::isFinished() const 
+bool KTransfer::isFinished() const
 {
    return impl()->isFinished();
 }
 
-bool KTransfer::isReady() const 
+bool KTransfer::isReady() const
 {
    return impl()->isReady();
 }
@@ -171,17 +176,17 @@ bool KTransfer::isRunnable(bool automatic) const
    return impl()->isRunnable(automatic);
 }
 
-bool KTransfer::isResumable() const 
+bool KTransfer::isResumable() const
 {
    return impl()->isResumable();
 }
 
-QTime KTransfer::estTime() const 
+QTime KTransfer::estTime() const
 {
    return impl()->estTime();
 }
 
-KURL KTransfer::getTempFile(const KURL &rmt, const KURL &lcl) const 
+KURL KTransfer::getTempFile(const KURL &rmt, const KURL &lcl) const
 {
    return impl()->getTempFile(rmt, lcl);
 }
@@ -207,8 +212,8 @@ bool KTransfer::startCheckResume() const
 }
 
 // CONFIG
-  
-bool KTransfer::getCheckResume() const 
+
+bool KTransfer::getCheckResume() const
 {
    return impl()->getCheckResume();
 }
@@ -218,7 +223,7 @@ void KTransfer::setCheckResume(bool c) const
    impl()->setCheckResume(c);
 }
 
-int KTransfer::getMaxResume() const 
+int KTransfer::getMaxResume() const
 {
    return impl()->getMaxResume();
 }
@@ -228,7 +233,7 @@ void KTransfer::setMaxResume(int r) const
    impl()->setMaxResume(r);
 }
 
-bool KTransfer::getAutoResume() const 
+bool KTransfer::getAutoResume() const
 {
    return impl()->getAutoResume();
 }
@@ -238,7 +243,7 @@ void KTransfer::setAutoResume(bool m) const
    impl()->setAutoResume(m);
 }
 
-int KTransfer::getWaitResume() const 
+int KTransfer::getWaitResume() const
 {
    return impl()->getWaitResume();
 }
@@ -248,7 +253,7 @@ void KTransfer::setWaitResume(int w) const
    impl()->setWaitResume(w);
 }
 
-int KTransfer::getMaxRetry() const 
+int KTransfer::getMaxRetry() const
 {
    return impl()->getMaxRetry();
 }
@@ -258,7 +263,7 @@ void KTransfer::setMaxRetry(int m) const
    impl()->setMaxRetry(m);
 }
 
-int KTransfer::getWaitRetry() const 
+int KTransfer::getWaitRetry() const
 {
    return impl()->getWaitRetry();
 }
@@ -268,7 +273,7 @@ void KTransfer::setWaitRetry(int w) const
    impl()->setWaitRetry(w);
 }
 
-bool KTransfer::getLogProcess() const 
+bool KTransfer::getLogProcess() const
 {
    return impl()->getLogProcess();
 }
@@ -279,8 +284,8 @@ void KTransfer::setLogProcess(bool l) const
 }
 
 const char * KTransfer::docId()
-{ 
-   return KTransferImpl::DOCID; 
+{
+   return KTransferImpl::DOCID;
 }
 
 const char * KTransfer::docType()
@@ -288,11 +293,11 @@ const char * KTransfer::docType()
    return KTransferImpl::DOCTYPE;
 }
 
-KTransfer::KTransfer(KTransferImpl * impl) : KObject(impl) 
+KTransfer::KTransfer(KTransferImpl * impl) : KObject(impl)
 {
 }
 
-KTransferImpl * KTransfer::impl() const 
+KTransferImpl * KTransfer::impl() const
 {
    return dynamic_cast<KTransferImpl*>(KObject::impl());
 }
