@@ -4,7 +4,7 @@
     begin                : Tue Oct 17 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.23 $
+    revision             : $Revision: 1.24 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,7 +30,7 @@ const char KTransferImpl::DOCID[] = "Transfer";
 const char KTransferImpl::DOCTYPE[] = "<!DOCTYPE Transfer >";
 
 
-KTransferImpl::KTransferImpl(int type) 
+KTransferImpl::KTransferImpl(int type)
    :  KObjectImpl(type), _state(TRN_START), _rsmState(RSM_UNKNOWN), _resumed(0),
       _lastBytesRead(0), _mediumBandwidth(0), _bandwidth(0), _killed(false),
       _retry(0), _checkResume(0)
@@ -48,7 +48,7 @@ KTransferImpl::~KTransferImpl()
 }
 
 /** load transfer from dom */
-void KTransferImpl::loadData() 
+void KTransferImpl::loadData()
 {
    KObjectImpl::loadData();
    kdDebug(D_INI) << name() << ": transfer loadData" << endl;
@@ -67,7 +67,7 @@ void KTransferImpl::loadData()
       setMaxRetry(3);
       setWaitRetry(2);
       setLogProcess(false);
-   }      
+   }
    // state
    _remote = dom().attribute("Remote");
    _local.setPath(dom().attribute("Local")); //FIXME !! is correct??
@@ -90,15 +90,15 @@ void KTransferImpl::loadData()
    _retry = 0;
 
    // config
-   _cfg_checkResume = dom().attribute("CheckResume", 
+   _cfg_checkResume = dom().attribute("CheckResume",
 				      QString::number(true)).toInt();
    _cfg_maxResume = dom().attribute("MaxResume", QString::number(10)).toInt();
-   _cfg_autoResume = dom().attribute("AutoResume", 
+   _cfg_autoResume = dom().attribute("AutoResume",
 				     QString::number(true)).toInt();
    _cfg_waitResume = dom().attribute("WaitResume", QString::number(20)).toInt();
    _cfg_maxRetry = dom().attribute("MaxRetry", QString::number(3)).toInt();
    _cfg_waitRetry = dom().attribute("WaitRetry", QString::number(2)).toInt();
-   _cfg_logProcess = dom().attribute("LogProcess", 
+   _cfg_logProcess = dom().attribute("LogProcess",
 				     QString::number(false)).toInt();
 
    kdDebug(D_INI) << name() << " :" << endl
@@ -106,19 +106,19 @@ void KTransferImpl::loadData()
 		  << " : lcl = " << _local.path() << endl
 		  << " : tmp = " << _tmp.path() << endl
 		  << " : state " << stateStr() << endl
-		  << " : rsmState " << resumeStr() << endl;   
+		  << " : rsmState " << resumeStr() << endl;
 }
 
-void KTransferImpl::checkState() 
+void KTransferImpl::checkState()
 {
    if (!isNormal())
       return;
    QFileInfo tmpfile(tmp().path());
    QFileInfo file(local().path());
-   if (tmpfile.exists()) 
+   if (tmpfile.exists())
    {
       // tmp file exists
-      if ((unsigned int)partial() != tmpfile.size()) 
+      if ((unsigned int)partial() != tmpfile.size())
       {
 	 kdWarning(D_INI) << name() << ": tmp file len (" << tmpfile.size() << ") != partial (" << partial() << ")" << endl;
 	 setPartial(tmpfile.size());
@@ -128,19 +128,19 @@ void KTransferImpl::checkState()
 	 // transfer is complete, move tmp to final
 	 moveTmp();
    }
-   else if (file.exists()) 
+   else if (file.exists())
    {
       // tmp file doesn't exists, but exists final file
-      if ((unsigned int)len() != file.size()) 
+      if ((unsigned int)len() != file.size())
       {
 	 kdWarning(D_INI) << name() << ": file len (" << file.size() << ") != len (" << len() << ")" << endl;
 	 //setLen(file.size());
       }
    }
-   else 
+   else
    {
       // either file and tmp doesn't exists
-      if (partial() != 0) 
+      if (partial() != 0)
       {
 	 kdWarning(D_INI) << name() << ": file len (" << file.size() << ") != len (" << len() << ")" << endl;
 	 clear();
@@ -152,14 +152,14 @@ void KTransferImpl::checkState()
       setState(TRN_READY);
 }
 
-const KTransferImpl * KTransferImpl::global() const 
-{ 
-   return dynamic_cast<const KTransferImpl*>(KObjectImpl::global()); 
+const KTransferImpl * KTransferImpl::global() const
+{
+   return dynamic_cast<const KTransferImpl*>(KObjectImpl::global());
 }
 
 QString KTransferImpl::stateStr(TrnState state)
 {
-   switch (state) 
+   switch (state)
    {
    case TRN_READY:
       return i18n("Ready");
@@ -184,7 +184,7 @@ QString KTransferImpl::stateStr(TrnState state)
    return QString::null;
 }
 
-QString KTransferImpl::progressStr() const 
+QString KTransferImpl::progressStr() const
 {
    if (partial() == 0)
       return i18n("Empty");
@@ -198,7 +198,7 @@ QString KTransferImpl::progressStr() const
 
 QString KTransferImpl::resumeStr(RsmState state)
 {
-   switch (state) 
+   switch (state)
    {
    case RSM_UNKNOWN:
       return i18n("???");
@@ -217,7 +217,7 @@ QString KTransferImpl::resumeStr(RsmState state)
 
 QString KTransferImpl::resumeString(RsmState state)
 {
-   switch (state) 
+   switch (state)
    {
    case RSM_UNKNOWN:
       return i18n("Unknown");
@@ -234,12 +234,12 @@ QString KTransferImpl::resumeString(RsmState state)
    return QString::null;
 };
 
-int KTransferImpl::cmpPriorityShort(const KObjectImpl *obj) const 
+int KTransferImpl::cmpPriorityShort(const KObjectImpl *obj) const
 {
    const KTransferImpl *t = dynamic_cast<const KTransferImpl*>(obj);
    // if you are comparing apple with oranges
    kdFatal(t == 0, D_RUN) << name() << ": cmpPriority type error in " << obj->name() << endl;
-   return (len() == t->len() ? 
+   return (len() == t->len() ?
 	   (id() > t->id() ? -1 : 1) : (len() > t->len() ? -1 : 1));
 }
 
@@ -248,11 +248,11 @@ int KTransferImpl::cmpPriorityLong(const KObjectImpl *obj) const
    const KTransferImpl *t = dynamic_cast<const KTransferImpl*>(obj);
    // if you are comparing apple with oranges
    kdFatal(t == 0, D_RUN) << name() << ": cmpPriority type error in " << obj->name() << endl;
-   return (len() == t->len() ? 
+   return (len() == t->len() ?
 	   (id() > t->id() ? -1 : 1) : (len() < t->len() ? -1 : 1));
 }
 
-KURL KTransferImpl::getTempFile(const KURL &, const KURL &lcl) const 
+KURL KTransferImpl::getTempFile(const KURL &, const KURL &lcl) const
 {
    KURL tmp;
    KTManagerImpl *parent = dynamic_cast<KTManagerImpl*>(container());
@@ -261,12 +261,12 @@ KURL KTransferImpl::getTempFile(const KURL &, const KURL &lcl) const
    return tmp;
 }
 
-bool KTransferImpl::isComplete() const 
+bool KTransferImpl::isComplete() const
 {
    return (state() == TRN_END_OK && partial() == len() && len() > 0);
 }
 
-void KTransferImpl::clear() 
+void KTransferImpl::clear()
 {
    QString tmpfile = tmp().path();
    QString file = local().path();
@@ -283,7 +283,7 @@ void KTransferImpl::clear()
    emitMod();
 }
 
-bool KTransferImpl::isRunning() const 
+bool KTransferImpl::isRunning() const
 {
    switch (state())
    {
@@ -297,7 +297,7 @@ bool KTransferImpl::isRunning() const
    return false;
 }
 
-bool KTransferImpl::isFinished() const 
+bool KTransferImpl::isFinished() const
 {
    switch (state())
    {
@@ -313,18 +313,18 @@ bool KTransferImpl::isFinished() const
    return false;
 }
 
-bool KTransferImpl::isRunnable(bool automatic) const 
+bool KTransferImpl::isRunnable(bool automatic) const
 {
    if (isComplete() || isRunning() || priority() == 0)
       return false;
    return
       ((automatic && state() == TRN_READY) // automatic download
        || ( state() == TRN_END_READY // resuming
-	    && getAutoResume() 
-	    && (isResumable() || rsmState() == RSM_UNKNOWN 
+	    && getAutoResume()
+	    && (isResumable() || rsmState() == RSM_UNKNOWN
 		|| rsmState() == RSM_CHECKFAIL)
 	    && ((!getMaxResume() || resumed() < getMaxResume())
-		|| (!getMaxResume() || resumed() == getMaxResume() 
+		|| (!getMaxResume() || resumed() == getMaxResume()
 		    && retry() < getMaxRetry())))
 	 );
 }
@@ -334,16 +334,16 @@ bool KTransferImpl::isRunnableInFuture(bool dLock, bool automatic) const
    return (!isComplete() && priority() > 0
 	   && ((!dLock && isRunnable(automatic)) // runnable now
 	       || (getAutoResume()
-		   && (isResumable() || rsmState() == RSM_UNKNOWN 
+		   && (isResumable() || rsmState() == RSM_UNKNOWN
 		       || rsmState() == RSM_CHECKFAIL)
 		   && (state() == TRN_END_OK || state() == TRN_END_ERROR)
-		   && ((!getMaxRetry() || retry() < getMaxRetry()) 
-		       || (!dLock && !getMaxResume() 
+		   && ((!getMaxRetry() || retry() < getMaxRetry())
+		       || (!dLock && !getMaxResume()
 			   || resumed() < getMaxResume())))));
 }
-	   
 
-void KTransferImpl::raiseFatalError() 
+
+void KTransferImpl::raiseFatalError()
 {
    if (getLogProcess()) {
       QString msg;
@@ -363,9 +363,9 @@ void KTransferImpl::raiseFatalError()
    emitMod();
 }
 
-void KTransferImpl::moveTmp() 
+void KTransferImpl::moveTmp()
 {
-   if (tmp() != local()) 
+   if (tmp() != local())
    {
       if (QDir::current().exists(local().path()))
 	 saveFile(local().path());
@@ -375,10 +375,10 @@ void KTransferImpl::moveTmp()
    }
 }
 
-bool KTransferImpl::start() 
+bool KTransferImpl::start()
 {
    kdDebug(D_RUN) << name() << ": " << stateStr() << ": start " << endl;
-   if (isRunning()) 
+   if (isRunning())
    {
       kdError(D_RUN) << name() << ": start a running process" << endl;
       return false;
@@ -400,13 +400,13 @@ bool KTransferImpl::start()
    return processStart();
 }
 
-bool KTransferImpl::startCheckResume() 
+bool KTransferImpl::startCheckResume()
 {
    _checkResume = 1;
    return start();
 }
 
-bool KTransferImpl::kill(bool wait) 
+bool KTransferImpl::kill(bool wait)
 {
    kdDebug(D_RUN) << name() << ":" << stateStr() << ": kill " << endl;
    //kdError(!isRunning(), D_RUN) << name() << ": kill process not running" << endl;
@@ -417,7 +417,7 @@ bool KTransferImpl::kill(bool wait)
       setState(TRN_END_KILL);
       return true;
    }
-   if (processKill()) 
+   if (processKill())
    {
       if (wait)
 	 waitForKill();
@@ -437,7 +437,7 @@ bool KTransferImpl::stop(bool wait)
    return false;
 }
 
-void KTransferImpl::opProcessStart() 
+void KTransferImpl::opProcessStart()
 {
    kdDebug(D_RUN) << name() << ":" << stateStr() << ": process start " << endl;
    kdFatal(!isReady(), D_RUN) << name() << ": process start with state " << stateStr() << endl;
@@ -450,10 +450,10 @@ void KTransferImpl::opProcessStart()
    _timeEst.setHMS(0, 0, 0);
    _killed = false;
    _stopped = false;
-   if (getLogProcess()) 
+   if (getLogProcess())
    {
       QString logname = QFileInfo(
-	 dynamic_cast<KTManagerImpl*>(container())->getWorkingDir(), 
+	 dynamic_cast<KTManagerImpl*>(container())->getWorkingDir(),
 	 local().fileName() + ".log").absFilePath();
       _logFile.setName(logname);
       _logFile.open(IO_WriteOnly | IO_Append);
@@ -472,7 +472,7 @@ void KTransferImpl::opProcessStart()
    emitMod();
 }
 
-void KTransferImpl::opConnect() 
+void KTransferImpl::opConnect()
 {
    kdDebug(D_RUN) << name() << ": " << stateStr() << " : connect " << endl;
    setState(TRN_CONNECT);
@@ -480,7 +480,7 @@ void KTransferImpl::opConnect()
    emitMod();
 }
 
-void KTransferImpl::opDownload() 
+void KTransferImpl::opDownload()
 {
    kdDebug(D_RUN) << name() << ": " << stateStr() << " : download p=" << partial() << ",l=" << len() << endl;
    _timeStart.start();
@@ -492,11 +492,15 @@ void KTransferImpl::opDownload()
    emitMod();
 }
 
-void KTransferImpl::opDataRead(int datalen) 
+void KTransferImpl::opDataRead(int datalen)
 {
    kdDebug(D_RUN) << name() << ": " << stateStr() << " : read data " << datalen << endl;
    kdError(state() != TRN_DOWNLOAD, D_RUN) << name() << ": opDataRead not int Download State" << endl;
+   int oldPercent = percent();
    setPartial(partial() + datalen);
+   int newPercent = percent();
+   if (newPercent != oldPercent)
+      emit sigPercent(newPercent);
 }
 
 void KTransferImpl::opCheckResume(RsmState newState)
@@ -510,7 +514,7 @@ void KTransferImpl::opCheckResume(RsmState newState)
    }
 }
 
-void KTransferImpl::opError(const QString &err) 
+void KTransferImpl::opError(const QString &err)
 {
    // signal an error, but continue the normal operations
    kdDebug(D_RUN) << name() << ": " << stateStr() << " : error " << err << endl;
@@ -520,7 +524,7 @@ void KTransferImpl::opError(const QString &err)
    //FIXME problems to maintain message visible
 }
 
-void KTransferImpl::opFatalError(const QString &err) 
+void KTransferImpl::opFatalError(const QString &err)
 {
    // signal a fatal error, kill the current transfer
    kdDebug(D_RUN) << name() << ": " << stateStr() << " : fatal error :" << err << endl;
@@ -530,7 +534,7 @@ void KTransferImpl::opFatalError(const QString &err)
       kill();
 }
 
-void KTransferImpl::opProcessEnd(int exitStatus) 
+void KTransferImpl::opProcessEnd(int exitStatus)
 {
    kdDebug(D_RUN) << name() << ": " << stateStr() << " : process end " << exitStatus << endl;
 
@@ -542,13 +546,13 @@ void KTransferImpl::opProcessEnd(int exitStatus)
    setMod(MDI_STOP);
 
    // analyze the returned state
-   if (!isFinished()) 
+   if (!isFinished())
    {
       opFatalError(QString("%1 : exit state not correct").arg(stateStr()));
    }
 
    // check for fatal errors
-   if (fatalError()) 
+   if (fatalError())
    {
       raiseFatalError();
       setState(TRN_END_FATAL);
@@ -560,7 +564,7 @@ void KTransferImpl::opProcessEnd(int exitStatus)
    if (_checkResume != 0)
    {
       kdDebug(D_RUN) << name() << ": check resume end : " << stateStr() << endl;
-      switch (rsmState()) 
+      switch (rsmState())
       {
       case RSM_UNKNOWN:
       case RSM_CHECKING:
@@ -576,7 +580,7 @@ void KTransferImpl::opProcessEnd(int exitStatus)
 	 kdFatal(D_RUN) << name() << ": unknown resume state :" << rsmState() << endl;
       }
       processCheckResumeEnd();
-      if ((state() == TRN_END_OK || state() == TRN_END_KILL 
+      if ((state() == TRN_END_OK || state() == TRN_END_KILL
 	   || state() == TRN_END_ERROR))
       {
 	 if (_checkResume == 1)
@@ -591,7 +595,7 @@ void KTransferImpl::opProcessEnd(int exitStatus)
    }
 
    // check for completeness and determine what to do
-   if (isComplete()) 
+   if (isComplete())
    {
       // transfer complete, move tmp to final
       moveTmp();
@@ -623,18 +627,18 @@ void KTransferImpl::opProcessEnd(int exitStatus)
    emitMod();
 }
 
-void KTransferImpl::opProcessOutput(const QString &data) 
+void KTransferImpl::opProcessOutput(const QString &data)
 {
    if (getLogProcess())
       _logFile.writeBlock(data, data.length());
    emit sigProcessOutput(data);
 }
 
-void KTransferImpl::calcBandwidth() 
+void KTransferImpl::calcBandwidth()
 {
    int time = _lastSampleTime.elapsed();
    // FIXME!! gestisci meglio intervallo di campionamento
-   if (time > 0) 
+   if (time > 0)
    {
       setMod(MDI_BAND);
       // calculate instantaneous bandwidth
@@ -648,7 +652,7 @@ void KTransferImpl::calcBandwidth()
    //debug("READ %l %l", _bandwidth, _mediumBandwidth);//(const char*)_parsebuf);
 }
 
-QTime KTransferImpl::estTime() 
+QTime KTransferImpl::estTime()
 {
    if (mediumBandwidth())
       return QTime().addSecs((len() - partial())/ mediumBandwidth());
@@ -697,7 +701,7 @@ void KTransferImpl::setTmp(const KURL &t)
    root()->setModified();
 }
 
-void KTransferImpl::setLen(int l) 
+void KTransferImpl::setLen(int l)
 {
    kdDebug(D_RUN) << name() << " set len = " << l << endl;
    _len = l;
@@ -706,7 +710,7 @@ void KTransferImpl::setLen(int l)
    root()->setModified();
 }
 
-void KTransferImpl::setPartial(int p) 
+void KTransferImpl::setPartial(int p)
 {
    kdDebug(D_RUN) << name() << " set partial = " << p << endl;
    _partial = p;
@@ -716,8 +720,8 @@ void KTransferImpl::setPartial(int p)
 }
 
 
-void KTransferImpl::setState(TrnState s) 
-{ 
+void KTransferImpl::setState(TrnState s)
+{
    if (_state != s)
    {
       _state = s;
@@ -727,14 +731,14 @@ void KTransferImpl::setState(TrnState s)
    }
 }
 
-void KTransferImpl::setRetry(int r) 
+void KTransferImpl::setRetry(int r)
 {
    _retry = r;
    setMod(MDI_TRN_RETRY);
    root()->setModified();
 }
 
-void KTransferImpl::setResumed(int r) 
+void KTransferImpl::setResumed(int r)
 {
    _resumed = r;
    dom().setAttribute("Resumed", _resumed);
@@ -742,9 +746,9 @@ void KTransferImpl::setResumed(int r)
    root()->setModified();
 }
 
-void KTransferImpl::setRsmState(RsmState s) 
-{ 
-   _rsmState = s; 
+void KTransferImpl::setRsmState(RsmState s)
+{
+   _rsmState = s;
    dom().setAttribute("ResumeState", _rsmState);
    setMod(MDI_TRN_RSMSTATE);
    root()->setModified();
@@ -752,112 +756,112 @@ void KTransferImpl::setRsmState(RsmState s)
 
 /////////// config entries
 
-bool KTransferImpl::getCheckResume() const 
+bool KTransferImpl::getCheckResume() const
 {
    return useGlobal() ? global()->getCheckResume() : _cfg_checkResume;
 }
 
-void KTransferImpl::setCheckResume(bool c) 
-{ 
+void KTransferImpl::setCheckResume(bool c)
+{
    if (_cfg_checkResume != c)
    {
-      _cfg_checkResume = c; 
+      _cfg_checkResume = c;
       dom().setAttribute("CheckResume", _cfg_checkResume);
       setMod(MDI_TRN_CFG_CHKRESUME);
       root()->setModified();
    }
 }
-	
-int KTransferImpl::getMaxResume() const 
+
+int KTransferImpl::getMaxResume() const
 {
    return useGlobal() ? global()->getMaxResume() : _cfg_maxResume;
 }
 
-void KTransferImpl::setMaxResume(int r) 
-{ 
+void KTransferImpl::setMaxResume(int r)
+{
    if (_cfg_maxResume != r)
    {
-      _cfg_maxResume = r; 
+      _cfg_maxResume = r;
       dom().setAttribute("MaxResume", _cfg_maxResume);
       setMod(MDI_TRN_CFG_MAXRESUME);
       root()->setModified();
    }
 }
-	
-bool KTransferImpl::getAutoResume() const 
+
+bool KTransferImpl::getAutoResume() const
 {
    return useGlobal() ? global()->getAutoResume() : _cfg_autoResume;
 }
 
-void KTransferImpl::setAutoResume(bool m) 
-{ 
+void KTransferImpl::setAutoResume(bool m)
+{
    if (_cfg_autoResume != m)
    {
-      _cfg_autoResume = m; 
+      _cfg_autoResume = m;
       dom().setAttribute("AutoResume", _cfg_autoResume);
       setMod(MDI_TRN_CFG_AUTORESUME);
       root()->setModified();
    }
 }
 
-int KTransferImpl::getWaitResume() const 
+int KTransferImpl::getWaitResume() const
 {
    return useGlobal() ? global()->getWaitResume() : _cfg_waitResume;
 }
 
-void KTransferImpl::setWaitResume(int w) 
-{ 
+void KTransferImpl::setWaitResume(int w)
+{
    if (_cfg_waitResume != w)
    {
-      _cfg_waitResume = w; 
+      _cfg_waitResume = w;
       dom().setAttribute("WaitResume", _cfg_waitResume);
       setMod(MDI_TRN_CFG_WAITRESUME);
       root()->setModified();
    }
 }
 
-int KTransferImpl::getWaitRetry() const 
+int KTransferImpl::getWaitRetry() const
 {
    return useGlobal() ? global()->getWaitRetry() : _cfg_waitRetry;
 }
 
-int KTransferImpl::getMaxRetry() const 
+int KTransferImpl::getMaxRetry() const
 {
    return useGlobal() ? global()->getMaxRetry() : _cfg_maxRetry;
 }
 
-void KTransferImpl::setMaxRetry(int m) 
-{ 
+void KTransferImpl::setMaxRetry(int m)
+{
    if (_cfg_maxRetry != m)
    {
-      _cfg_maxRetry = m; 
+      _cfg_maxRetry = m;
       dom().setAttribute("MaxRetry", _cfg_maxRetry);
       setMod(MDI_TRN_CFG_MAXRETRY);
       root()->setModified();
    }
 }
 
-void KTransferImpl::setWaitRetry(int w) 
-{ 
+void KTransferImpl::setWaitRetry(int w)
+{
    if (_cfg_waitRetry != w)
    {
-      _cfg_waitRetry = w; 
+      _cfg_waitRetry = w;
       dom().setAttribute("WaitRetry", _cfg_waitRetry);
       setMod(MDI_TRN_CFG_WAITRETRY);
       root()->setModified();
    }
 }
 
-bool KTransferImpl::getLogProcess() const 
+bool KTransferImpl::getLogProcess() const
 {
    return useGlobal() ? global()->getLogProcess() : _cfg_logProcess;
 }
 
-void KTransferImpl::setLogProcess(bool l) 
-{ 
+void KTransferImpl::setLogProcess(bool l)
+{
    if (_cfg_logProcess != l)
    {
-      _cfg_logProcess = l; 
+      _cfg_logProcess = l;
       dom().setAttribute("LogProcess", _cfg_logProcess);
       setMod(MDI_TRN_CFG_LOGPROCESS);
       root()->setModified();
@@ -866,7 +870,7 @@ void KTransferImpl::setLogProcess(bool l)
 
 //////////////  SLOTS
 
-void KTransferImpl::slotTimeout() 
+void KTransferImpl::slotTimeout()
 {
    // set the transfer ready for processing
    setState(TRN_END_READY);
