@@ -4,7 +4,7 @@
     begin                : Mon Oct 16 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.16 $
+    revision             : $Revision: 1.17 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,7 +36,7 @@ class KTransfer;
  * @version $Id
  */
 
-class KTransferImpl : public KObjectImpl 
+class KTransferImpl : public KObjectImpl
 {
    Q_OBJECT
 
@@ -45,7 +45,7 @@ class KTransferImpl : public KObjectImpl
 public:
    static const char DOCID[];
    static const char DOCTYPE[];
-   
+
    virtual ~KTransferImpl();
 
    /** document name */
@@ -53,13 +53,13 @@ public:
 
    /** dom document type */
    virtual const char * docType() const { return DOCTYPE; }
-   
+
    // references to other objects
-   
+
    /** reference to global instance */
    const KTransferImpl * global() const;
 
-   /** length of remote file, it can be 0 if length is unknown or not yet 
+   /** length of remote file, it can be 0 if length is unknown or not yet
     * retrieved
     */
    int len() const { return _len; }
@@ -67,6 +67,9 @@ public:
    /** length of partial retrieved data */
    int partial() const { return _partial; }
 
+   /** percent */
+   int percent() const { return (len() != 0 ? int(100.0 * partial() / len()) : 0); }
+
    /** number of retries done */
    int retry() const { return _retry; }
 
@@ -131,7 +134,7 @@ public:
 
    /** get the temporary file */
    const KURL & tmp() const { return _tmp; }
-   
+
    /** get number of resumes */
    int resumed() const { return _resumed; }
 
@@ -153,7 +156,7 @@ public:
    virtual bool isFinished() const;
 
    /** check if transfer is ready */
-   virtual bool isReady() const 
+   virtual bool isReady() const
       { return (state() == TRN_READY || state() == TRN_END_READY); }
 
    /** check if the transfer can be started */
@@ -171,7 +174,7 @@ public:
    /** guess the name of the temporary file based on rmt or lcl urls */
    virtual KURL getTempFile(const KURL &rmt, const KURL &lcl) const;
 
-   /** start the transfer 
+   /** start the transfer
     * @returns false on errors
     */
    virtual bool start();
@@ -181,14 +184,14 @@ public:
     */
    virtual bool startCheckResume();
 
-   /** 
-    * kill the transfer 
+   /**
+    * kill the transfer
     * @param wait	wait for transfer to finish
     * @returns false on errors
     */
    virtual bool kill(bool wait = false);
 
-   /** 
+   /**
     * kill the transfer, set state to TRN_END_OK, decrease priority
     */
    virtual bool stop(bool wait = false);
@@ -202,7 +205,7 @@ public:
    virtual void runPeriodically();
 
    // CONFIG
-  
+
    bool getCheckResume() const;
    void setCheckResume(bool c);
    int getMaxResume() const;
@@ -217,7 +220,7 @@ public:
    void setWaitRetry(int w);
    bool getLogProcess() const;
    void setLogProcess(bool l);
-  
+
 protected:
    KTransferImpl(int type);
 
@@ -271,7 +274,7 @@ protected:
    // operations that derived class have to call to maintain the state
 
    /** called when process start */
-   virtual void opProcessStart(); 
+   virtual void opProcessStart();
 
    /** called when process end */
    virtual void opProcessEnd(int exitStatus);
@@ -308,6 +311,8 @@ protected slots:
 signals:
    /** forward process output */
    void sigProcessOutput(const QString &data);
+   /** emit percent */
+   void sigPercent(int);
 
 private: // Private state attributes
    /** url to dowload */
@@ -352,7 +357,7 @@ private: // Private state attributes
    int _partial;
    /** true when running in check resume mode */
    int _checkResume;
-  
+
    // config attributes
 
    /** check for resumable */
