@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.9 $
+    revision             : $Revision: 1.11 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,7 +28,10 @@
 #include <math.h>
 #include "utils.h"
 
-bool checkFilePermission(const QFileInfo &file) 
+extern bool _uniqueApp;
+extern bool _singleDoc;
+
+bool checkFilePermission(const QFileInfo &file)
 {
    if (file.permission(QFileInfo::ReadUser | QFileInfo::WriteUser))
       return true;
@@ -40,11 +43,11 @@ bool checkFilePermission(const QFileInfo &file)
    return false;
 }
 
-bool checkFileCreation(const QFileInfo &file) 
+bool checkFileCreation(const QFileInfo &file)
 {
    // create file
    QFile f(file.absFilePath());
-   if (!f.open(IO_ReadWrite)) 
+   if (!f.open(IO_ReadWrite))
    {
       KMessageBox::sorry(kapp->mainWidget(),
 			 i18n("Error in creation of file " + file.absFilePath()),
@@ -56,7 +59,7 @@ bool checkFileCreation(const QFileInfo &file)
    return true;
 }
 
-bool promptFileOverwrite(const QFileInfo &file) 
+bool promptFileOverwrite(const QFileInfo &file)
 {
    return KMessageBox::questionYesNo(
       kapp->mainWidget(),
@@ -65,7 +68,7 @@ bool promptFileOverwrite(const QFileInfo &file)
       QString::null, QString::null, false) == KMessageBox::Yes;
 }
 
-bool promptFileCreate(const QFileInfo &file) 
+bool promptFileCreate(const QFileInfo &file)
 {
    return KMessageBox::questionYesNo(
       kapp->mainWidget(),
@@ -78,23 +81,23 @@ bool promptFileCreate(const QFileInfo &file)
 	* mod = ASK_IFEXIST 		-> ask to overwrite if file exits
 	* mod = DONT_ASK 				-> don't ask
 	*/
-bool promptFileOpen(const QFileInfo &file, int mod = ASK_IFEXIST) 
+bool promptFileOpen(const QFileInfo &file, int mod = ASK_IFEXIST)
 {
    if (!file.exists() &&
        mod == ASK_IFNOTEXIST &&
        promptFileCreate(file))
       return checkFileCreation(file);
-   
+
    if (file.exists() &&
        mod == ASK_IFEXIST &&
        promptFileOverwrite(file))
       return checkFilePermission(file);
-  
+
    return true;
 }
 
 /** open a message box with the prompt for the add mode */
-int promptStartMode(const QString &caption, const QString &message) 
+int promptStartMode(const QString &caption, const QString &message)
 {
    return KMessageBox::warningYesNoCancel(kapp->mainWidget(),
 					  message,
@@ -105,12 +108,12 @@ int promptStartMode(const QString &caption, const QString &message)
 }
 
 /** select which file to recover */
-int promptFilesToRecover(const QString &f1, const QString &f2) 
+int promptFilesToRecover(const QString &f1, const QString &f2)
 {
    int retval;
    retval = KMessageBox::warningYesNoCancel(
       kapp->mainWidget(),
-      i18n("Files\n" + f1 + "\n" + f2 + "\nalready existing, do you want to recover?"),
+      i18n("Files\n") + f1 + "\n" + f2 + i18n("\nalready existing, do you want to recover?"),
       i18n("Recover File"),
       QString::null, QString::null, false);
 
@@ -119,19 +122,19 @@ int promptFilesToRecover(const QString &f1, const QString &f2)
 
    retval = KMessageBox::warningYesNoCancel(
       kapp->mainWidget(),
-      i18n("Select file to recover:\nFile A:" + f1 + "\nFile B:" + f2),
+      i18n("Select file to recover:\nFile A:") + f1 + i18n("\nFile B:") + f2,
       i18n("Recover File"),
       i18n("File A"),
       i18n("File B"), false);
 
    if (retval == KMessageBox::Cancel)
       return retval;
-   
+
    return  retval == KMessageBox::Yes ? KMessageBox::Ok : KMessageBox::Yes;
 }
 
 /** prompt to recover file */
-int promptFileToRecover(const QString &f) 
+int promptFileToRecover(const QString &f)
 {
    return KMessageBox::warningYesNoCancel(
       kapp->mainWidget(),
@@ -141,7 +144,7 @@ int promptFileToRecover(const QString &f)
 }
 
 /** create a tmp filename */
-QString tempFile() 
+QString tempFile()
 {
    //FIXME!!
    char templ[40] = "/tmp/kmagoXXXXXX";
@@ -152,11 +155,11 @@ QString tempFile()
 }
 
 /** transform a number of type 100,000 to 100000*/
-int parseNumber(const QString& num) 
+int parseNumber(const QString& num)
 {
    QString tmp = num;
    int p;
-   while ((p = tmp.find(',')) != -1) 
+   while ((p = tmp.find(',')) != -1)
    {
       tmp.remove(p, 1);
    }
@@ -164,16 +167,16 @@ int parseNumber(const QString& num)
 }
 
 /** save a file moving it to file.NN */
-QString saveFile(const QString &f) 
+QString saveFile(const QString &f)
 {
    int i = 0;
    QFileInfo tmpfile, file(f);
-   do 
+   do
    {
       i++;
       tmpfile.setFile(file.dir(), QString("%1.%2").arg(file.fileName()).arg(i));
    } while (tmpfile.exists());
-   bool check = 
+   bool check =
       QDir::current().rename(file.absFilePath(), tmpfile.absFilePath());
    if (!check)
    {
@@ -183,7 +186,7 @@ QString saveFile(const QString &f)
    return tmpfile.absFilePath();
 }
 
-static QString unitk(float val) 
+static QString unitk(float val)
 {
    QString str;
    if (val < 10)
@@ -194,7 +197,7 @@ static QString unitk(float val)
    return str.sprintf("%4.0f", val);
 }
 
-QString unit(float val) 
+QString unit(float val)
 {
    float v = fabs(val);
    if (v < 1e3)
@@ -211,17 +214,17 @@ QString unit(float val)
 }
 
 /** copy file source to dest */
-bool copyFile(const QString &source, const QString &dest) 
+bool copyFile(const QString &source, const QString &dest)
 {
    QFile s(source), d(dest);
    if (!s.open(IO_ReadOnly))
       return false;
-   if (!d.open(IO_WriteOnly | IO_Truncate)) 
+   if (!d.open(IO_WriteOnly | IO_Truncate))
    {
       s.close();
       return false;
    }
-   while (!s.atEnd()) 
+   while (!s.atEnd())
    {
       char buf[1024];
       int len = s.readBlock(buf, 1024);
@@ -236,8 +239,14 @@ bool copyFile(const QString &source, const QString &dest)
 
 bool isUniqueApp()
 {
-   return dynamic_cast<KUniqueApplication*>(kapp) != 0;
+   return _uniqueApp;
 }
+
+bool isSingleDoc()
+{
+   return _singleDoc;
+}
+
 /*
 uint mem()
 {
@@ -246,16 +255,16 @@ uint mem()
    QFile f(statfile);
    f.open(IO_ReadOnly);
    QTextStream s(&f);
-   int pid, ppid, pgrp, session, tty, tpgid, utime, stime, cutime, cstime, 
+   int pid, ppid, pgrp, session, tty, tpgid, utime, stime, cutime, cstime,
       counter, priority, starttime;
-   uint flags, minflt, cminflt, majflt, cmajflt, timeout, itrealvalue, vsize, 
+   uint flags, minflt, cminflt, majflt, cmajflt, timeout, itrealvalue, vsize,
       rss;
    QString comm;
    char state;
-   
+
    s >> pid >> comm >> state >> ppid >> pgrp >> session >> tty >> tpgid >> flags
-     >> minflt >> cminflt >> majflt >> cmajflt >> utime >> stime >> cutime 
-     >> cstime >> counter >> priority >> timeout >> itrealvalue >> starttime 
+     >> minflt >> cminflt >> majflt >> cmajflt >> utime >> stime >> cutime
+     >> cstime >> counter >> priority >> timeout >> itrealvalue >> starttime
      >> vsize >> rss;
    f.close();
    return vsize;
