@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.7 $
+    revision             : $Revision: 1.8 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -55,6 +55,8 @@ QString unit(float val);
 bool copyFile(const QString &source, const QString &dest);
 /** true if app is running as unique */
 bool isUniqueApp();
+/** true if app is running as single-document */
+bool isSingleDoc();
 //uint mem();
 
 #endif
